// (Copyright) [2016 - 2016] Confluent, Inc.
package io.confluent.kafka.databalancing;

import io.confluent.kafka.databalancing.metric.Metrics;
import io.confluent.kafka.databalancing.topology.Broker;
import io.confluent.kafka.databalancing.topology.ReplicaAssignment;
import kafka.admin.BrokerMetadata;

import java.util.List;

public class InMemoryRebalancer extends AbstractRebalancer {

    private final RebalancePolicy rebalancePolicy = new MovesOptimisedRebalancePolicy();
    private final List<BrokerMetadata> allBrokers;
    private final Metrics metrics;
    private final RebalanceStatus status;

    private ReplicaAssignment currentAssignment;

    public InMemoryRebalancer(List<BrokerMetadata> allBrokers, ReplicaAssignment currentAssignment,
                              Metrics metrics, RebalanceStatus status) {
        this.currentAssignment = currentAssignment;
        this.allBrokers = allBrokers;
        this.metrics = metrics;
        this.status = status;
    }

    @Override
    public boolean maybeUpdateReplicationQuota(ReplicaAssignment inProgressAssignment, long replicationQuota) {
        if (!status.inProgressAssignment().isEmpty()) {
            System.out.println("The throttle rate was updated to " + replicationQuota + " bytes/sec.");
            return true;
        }
        return false;
    }

    @Override
    public ProposedRebalance proposeRebalance(List<Integer> brokerIdsToRemove, RebalancerConfig config) {
        if (!status.inProgressAssignment().isEmpty())
            throw partitionsBeingReassignedException(status.inProgressAssignment().topicPartitions());

        List<Broker> brokersToRemove = brokersToRemove(allBrokers, currentAssignment, brokerIdsToRemove);
        ReplicaAssignment proposedAssignment = rebalancePolicy.rebalancePartitions(allBrokers, currentAssignment,
                currentAssignment.replicationFactors(), metrics, brokersToRemove);
        return new ProposedRebalance(allBrokers, currentAssignment, proposedAssignment, metrics, brokersToRemove);
    }

    @Override
    public void startRebalance(ReplicaAssignment currentAssignment, ReplicaAssignment proposedAssignment, long replicationQuota) {
        this.currentAssignment = proposedAssignment;
    }

    @Override
    public boolean disengageThrottle() {
        return false;
    }

    @Override
    public RebalanceStatus status() {
        return status;
    }

    @Override
    public void close() {}

}
