// (Copyright) [2016 - 2016] Confluent, Inc.
package io.confluent.kafka.databalancing;

import org.apache.kafka.common.config.AbstractConfig;
import org.apache.kafka.common.config.ConfigDef;
import java.util.Properties;

public class RebalancerConfig extends AbstractConfig {
    public static final String BASE_PREFIX = "confluent.rebalancer.";
    public static final String METRICS_PREFIX = RebalancerConfig.BASE_PREFIX + "metrics.";

    public static final String METRICS_BOOTSTRAP_SERVERS_CONFIG = RebalancerConfig.METRICS_PREFIX + "bootstrap.servers";
    public static final String DEFAULT_METRICS_BOOTSTRAP_SERVERS = "";
    protected static final String METRICS_BOOTSTRAP_SERVERS_DOC = "The kafka brokers where the " +
            "metrics reporter publishes cluster level metrics to. These metrics are needed to make decisions about " +
            "where to place cluster data.";

    public static final String METRICS_TOPIC_CONFIG = RebalancerConfig.METRICS_PREFIX + "topic";
    public static final String DEFAULT_METRICS_TOPIC = "_confluent-metrics";
    protected static final String METRICS_TOPIC_DOC = "The topic where the metrics reporter publishes its metrics to";


    public static final String LICENSE_CONFIG = RebalancerConfig.BASE_PREFIX + "license";
    public static final String DEFAULT_LICENSE = "";
    protected static final String LICENSE_DOC = "Confluent will issue a license key to each subscriber. "
                  + "The license key will be a short snippet of text that you can copy and paste. "
                  + "Without the license key, you can use the Confluent Rebalancer for a 30-day trial period. "
                  + "If you are a subscriber, please contact Confluent Support for more information.";

    private static final ConfigDef config;

    static {
        config = new ConfigDef()
            .define(METRICS_BOOTSTRAP_SERVERS_CONFIG,
                    ConfigDef.Type.STRING,
                    DEFAULT_METRICS_BOOTSTRAP_SERVERS,
                    ConfigDef.Importance.HIGH,
                    METRICS_BOOTSTRAP_SERVERS_DOC
            )
            .define(METRICS_TOPIC_CONFIG,
                    ConfigDef.Type.STRING,
                    DEFAULT_METRICS_TOPIC,
                    ConfigDef.Importance.LOW,
                    METRICS_TOPIC_DOC
            )
            .define(LICENSE_CONFIG,
                    ConfigDef.Type.STRING,
                    DEFAULT_LICENSE,
                    ConfigDef.Importance.HIGH,
                    LICENSE_DOC
            );
   }

    public RebalancerConfig(Properties props) {
        super(config, props);
    }

    public boolean isTrial() {
        return getString(LICENSE_CONFIG).equals(DEFAULT_LICENSE);
    }

    public String licenseString() {
        return getString(LICENSE_CONFIG);
    }

}
