// (Copyright) [2016 - 2016] Confluent, Inc.
package io.confluent.kafka.databalancing.fairness;

import io.confluent.kafka.databalancing.RebalanceContext;
import io.confluent.kafka.databalancing.topology.Broker;
import io.confluent.kafka.databalancing.topology.TopologyUtils;
import org.apache.kafka.common.TopicPartition;

import java.util.Collection;
import java.util.Map;

import static io.confluent.kafka.databalancing.topology.TopologyUtils.brokerLeaderCounts;
import static io.confluent.kafka.databalancing.topology.TopologyUtils.rackLeaderCounts;

public class LeaderCountFairness extends LeaderFairness {

    public LeaderCountFairness(RebalanceContext context, String rack, String topic) {
        super(context, rack, topic);
    }

    @Override
    protected Map<Broker, Long> createBrokerValueMap(RebalanceContext context, String rack, String topic) {
        Collection<Broker> brokers = TopologyUtils.availableBrokersOnRack(context, rack);
        return brokerLeaderCounts(context, brokers, topic);
    }

    @Override
    protected Map<String, Long> createRackValueMap(RebalanceContext context, String rack, String topic) {
        return rackLeaderCounts(context, rack, topic);
    }

    @Override
    protected long partitionValue(TopicPartition tp) {
        if (topic == null || topic.equals(tp.topic()))
            return 1;
        else
            return 0;
    }

}
