// (Copyright) [2016 - 2016] Confluent, Inc.
package io.confluent.kafka.databalancing.license;

/**
 * Verify a user's license or trial period.
 */
public interface LicenseValidator {

    class ValidationFailedException extends Exception {
        ValidationFailedException(String message) {
            super(message);
        }

        ValidationFailedException(String message, Throwable cause) {
            super(message, cause);
        }
    }

    /**
     * Verify a users license.
     * @param licenseStr The license string.
     * @throws ValidationFailedException if the license is invalid or has expired.
     */
    void validateLicense(String licenseStr) throws ValidationFailedException;

    /**
     * Validate the trial period.
     * @param zkConnect The zookeeper cluster where trial information is stored.
     * @return the amount of time left in the trial. 0 if the trial has expired.
     */
    long validateTrialPeriod(String zkConnect);
}
