// (Copyright) [2016 - 2016] Confluent, Inc.
package io.confluent.kafka.databalancing.view;

import io.confluent.kafka.databalancing.CompareResult;
import io.confluent.kafka.databalancing.RebalanceContext;
import io.confluent.kafka.databalancing.fairness.LeaderCountFairness;
import io.confluent.kafka.databalancing.fairness.LeaderFairness;
import io.confluent.kafka.databalancing.fairness.ReplicaCountFairness;
import io.confluent.kafka.databalancing.fairness.ReplicaFairness;
import io.confluent.kafka.databalancing.topology.Broker;
import io.confluent.kafka.databalancing.topology.Replica;
import io.confluent.kafka.databalancing.topology.TopologyUtils;
import org.apache.kafka.common.TopicPartition;

import java.util.List;

public class BrokerCountFairView extends BrokerFairView {

    /**
     * @param context required
     * @param rack nullable
     * @param topic nullable
     */
    public BrokerCountFairView(RebalanceContext context, String rack, String topic) {
        super(context, rack, topic);
    }

    @Override
    protected List<TopicPartition> createLeadersOnAboveParBrokers(RebalanceContext context, LeaderFairness fairness,
                                                                  String topic) {
        return TopologyUtils.leaders(context, fairness.aboveParBrokers(), topic);
    }

    @Override
    protected List<Replica> createReplicasOnAboveParBrokers(RebalanceContext context, ReplicaFairness fairness, String topic) {
        return TopologyUtils.interleavedReplicas(context, fairness.aboveParBrokers(), topic);
    }

    @Override
    public ClusterView refresh(RebalanceContext context) {
        return new BrokerCountFairView(context, rack, topic);
    }

    @Override
    protected ReplicaFairness createReplicaFairness(RebalanceContext context, String rack, String topic) {
        return new ReplicaCountFairness(context, rack, topic);
    }

    @Override
    protected LeaderFairness createLeaderFairness(RebalanceContext context, String rack, String topic) {
        return new LeaderCountFairness(context, rack, topic);
    }

}
