// (Copyright) [2016 - 2016] Confluent, Inc.
package io.confluent.controlcenter;

import java.util.concurrent.TimeUnit;

/**
 * Holds info required to make/identify a metric rollup.
 */
public enum Rollup {
  FIFTEEN_SECONDS(TimeUnit.SECONDS.toMillis(15), TimeUnit.HOURS.toMillis(36)),
  ONE_HOUR(TimeUnit.HOURS.toMillis(1), TimeUnit.DAYS.toMillis(30)),
  ONE_WEEK(TimeUnit.DAYS.toMillis(7), TimeUnit.DAYS.toMillis(700));

  private final long millis;
  private final long retainMillis;

  Rollup(long millis, long retainMillis) {
    this.millis = millis;
    this.retainMillis = retainMillis;
  }

  /**
   * @return window size in millis for this rollup
   */
  public long getMillis() {
    return millis;
  }

  /**
   * @return window size in millis that we should accept samples
   */
  public long getRetainMillis() {
    return retainMillis;
  }

  /**
   * @return value from getRetainMillis() converted to seconds
   */
  public long getRetainSeconds() {
    return TimeUnit.MILLISECONDS.toSeconds(retainMillis);
  }
}
