// (Copyright) [2016 - 2016] Confluent, Inc.
package io.confluent.controlcenter.license;

import com.google.inject.Binder;
import com.google.inject.Inject;
import com.google.inject.Module;
import com.google.inject.Provides;

import org.jose4j.jwt.JwtClaims;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import java.io.IOException;
import java.nio.file.Files;
import java.nio.file.Path;
import java.nio.file.Paths;
import java.nio.file.attribute.BasicFileAttributes;
import java.security.PublicKey;
import java.util.concurrent.TimeUnit;

import io.confluent.controlcenter.ControlCenterConfig;
import io.confluent.license.License;

public class LicenseModule implements Module {

  private static final Logger log = LoggerFactory.getLogger(LicenseModule.class);

  @Override
  public void configure(Binder binder) {
  }

  @Provides
  @Inject
  private JwtClaims provide(ControlCenterConfig controlCenterConfig) {
    String license = controlCenterConfig.getString(ControlCenterConfig.CONTROL_CENTER_LICENSE_CONFIG);
    try {
      PublicKey publicKey = License.loadPublicKey();
      return License.verify(publicKey, license);
    } catch (Exception e) {
      log.warn("checking license failure: {}", e.getMessage());
    }
    try {
      String dataDir = controlCenterConfig.getString(ControlCenterConfig.CONTROL_CENTER_DATA_DIR);
      Path demoLicensePath = Paths.get(dataDir, ".controlcenter");
      if (Files.notExists(demoLicensePath)) {
        Files.createFile(demoLicensePath);
      }
      BasicFileAttributes bfa = Files.readAttributes(demoLicensePath, BasicFileAttributes.class);
      return License.baseClaims("demo", bfa.creationTime().toMillis() + TimeUnit.DAYS.toMillis(30), true);
    } catch (IOException e) {
      log.warn("checking demo license failure: {} ", e.getMessage());
    }

    return License.baseClaims("demo", TimeUnit.HOURS.toMillis(1), false);
  }
}
