// (Copyright) [2016 - 2016] Confluent, Inc.
package io.confluent.controlcenter.rest;

import com.google.inject.Inject;
import com.google.inject.Provider;
import io.confluent.controlcenter.data.KafkaMetadataDao;
import io.confluent.controlcenter.record.Controlcenter.Cluster;
import io.confluent.controlcenter.record.Controlcenter.ClusterContext;
import io.confluent.controlcenter.rest.res.Topic;
import io.confluent.controlcenter.serialization.OrderedKeyPrefixedSerdeSupplier;
import io.confluent.controlcenter.streams.TopicStoreModule.ClusterStore;
import io.confluent.serializers.OrderedKeyPrefixedSerde;
import org.apache.kafka.common.utils.Bytes;
import org.apache.kafka.streams.state.ReadOnlyKeyValueStore;

import javax.ws.rs.GET;
import javax.ws.rs.NotFoundException;
import javax.ws.rs.Path;
import javax.ws.rs.PathParam;
import javax.ws.rs.Produces;
import javax.ws.rs.core.MediaType;
import java.util.List;

@Path("/2.0/kafka/")
@Produces(MediaType.APPLICATION_JSON)
public class KafkaResource {
  private final Provider<ReadOnlyKeyValueStore<Bytes, Cluster>> clusterStore;
  private final OrderedKeyPrefixedSerde<ClusterContext, Cluster> monitoringClusterPrefixKeySerde;
  private final KafkaMetadataDao kafkaMetadataDao;

  @Inject
  public KafkaResource(
      @ClusterStore Provider<ReadOnlyKeyValueStore<Bytes, Cluster>> clusterStore,
      OrderedKeyPrefixedSerdeSupplier<ClusterContext, Cluster> keySerdeSupplier,
      KafkaMetadataDao kafkaMetadataDao
  ) {
    this.clusterStore = clusterStore;
    this.monitoringClusterPrefixKeySerde = keySerdeSupplier.get(ClusterContext.STREAM_MONITORING).prefixKeySerde(1);
    this.kafkaMetadataDao = kafkaMetadataDao;
  }


  @GET
  @Path("{clusterId}/topics")
  public List<Topic> topics(
      @PathParam("clusterId") String clusterId
  ) {
    List<Topic> topics = kafkaMetadataDao.getTopics(clusterId, true);
    if (topics == null) {
      throw new NotFoundException("No such cluster: " + clusterId);
    }
    return topics;
  }

}
