package io.confluent.controlcenter.rest;

import com.google.common.base.Predicate;
import com.google.common.base.Strings;
import com.google.common.collect.ImmutableSet;
import com.google.common.collect.Iterables;
import com.google.inject.Binder;
import com.google.inject.BindingAnnotation;
import com.google.inject.Inject;
import com.google.inject.Module;
import com.google.inject.Provides;
import com.google.inject.Singleton;
import com.google.protobuf.GeneratedMessageV3;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import java.lang.annotation.ElementType;
import java.lang.annotation.Retention;
import java.lang.annotation.Target;
import java.util.Collection;
import java.util.Properties;

import io.confluent.command.record.alert.CommandAlert.ActionConfig;
import io.confluent.command.record.alert.CommandAlert.MonitoringTriggerConfig;
import io.confluent.controlcenter.ControlCenterConfig;
import io.confluent.rest.RestConfig;
import io.confluent.serializers.UberSerde;

import static java.lang.annotation.RetentionPolicy.RUNTIME;


public class RestModule implements Module {

  private static final Logger log = LoggerFactory.getLogger(RestModule.class);

  //TODO(norwood): this got removed in kafka trunk
  public static final String GROUP_METADATA_TOPIC_NAME = "__consumer_offsets";
  public static final Collection<String> IGNORE_TOPICS = ImmutableSet.of(GROUP_METADATA_TOPIC_NAME);

  @Override
  public void configure(Binder binder) {
  }

  @Provides
  @Singleton
  @Inject
  private RestConfig provideRestConfig(final ControlCenterConfig config) {
    Properties props = new Properties();
    props.putAll(config.valuesWithPrefix(ControlCenterConfig.CONFLUENT_CONTROLCENTER_REST_PREFIX));
    props.putAll(config.originalsWithPrefix(ControlCenterConfig.CONFLUENT_CONTROLCENTER_REST_PREFIX));
    return new RestConfig(RestConfig.baseConfigDef(), props);
  }

  @BindingAnnotation
  @Retention(RUNTIME)
  @Target({ElementType.FIELD, ElementType.PARAMETER, ElementType.METHOD})
  public @interface RestEndpoint {
  }

  @Provides
  @RestEndpoint
  @Singleton
  @Inject
  private String provideRestEndpoint(
      final RestConfig config,
      final ControlCenterConfig controlCenterConfig
  ) {
    if (!Strings.isNullOrEmpty(controlCenterConfig.getString(ControlCenterConfig.CONTROL_CENTER_DISPLAY_HOST_PREFIX))) {
      return controlCenterConfig.getString(ControlCenterConfig.CONTROL_CENTER_DISPLAY_HOST_PREFIX);
    }
    return Iterables.getFirst(
        Iterables.filter(
            config.getList(RestConfig.LISTENERS_CONFIG),
            new Predicate<String>() {
              @Override
              public boolean apply(String input) {
                return !Strings.isNullOrEmpty(input);
              }
            }
        ),
        "http://localhost:" + config.getInt(RestConfig.PORT_CONFIG)
    );
  }

  @Provides
  @Singleton
  @Inject
  public UberMessageBodyRW<MonitoringTriggerConfig> provideMonitoringTriggerConfigProtoMessageBodyRW(
      UberSerde<MonitoringTriggerConfig> monitoringTriggerConfigProtoSerde
  ) {
    return new UberMessageBodyRW<>(monitoringTriggerConfigProtoSerde);
  }

  @Provides
  @Singleton
  @Inject
  public UberMessageBodyRW<ActionConfig> provideActionConfigProtoMessageBodyRW(
      UberSerde<ActionConfig> actionConfigProtoSerde
  ) {
    return new UberMessageBodyRW<>(actionConfigProtoSerde);
  }

  @Provides
  @Singleton
  @Inject
  public UberMessageBodyRW<? extends GeneratedMessageV3> provideProtoMessageBodyRW(
      UberSerde<ActionConfig> actionConfigProtoSerde,
      UberSerde<MonitoringTriggerConfig> monitoringTriggerConfigProtoSerde
  ) {
    return new UberMessageBodyRW(ImmutableSet.of(actionConfigProtoSerde, monitoringTriggerConfigProtoSerde));
  }
}
