// (Copyright) [2016 - 2016] Confluent, Inc.
package io.confluent.controlcenter.rest;

import com.google.common.base.Strings;
import com.google.common.collect.Lists;

import java.util.ArrayList;
import java.util.List;

import io.confluent.controlcenter.record.Controlcenter.MemberInfo;
import io.confluent.controlcenter.rest.req.RangeRequest;
import io.confluent.monitoring.record.Monitoring.MonitoringMessage;

public class Util {

  public static ArrayList<Object> extractValues(
      List<MonitoringMessage> monitoringMessages,
      long rollup,
      long startTimeMs,
      long stopTimeMs,
      int max,
      Metric metric) {

    ArrayList<Object> result = Lists.newArrayList();
    Long startWindow = stopTimeMs;
    if (monitoringMessages.size() > 0) {
      startWindow = monitoringMessages.get(0).getWindow();
    }
    while (startTimeMs < startWindow && result.size() < max) {
      result.add(null);
      startTimeMs += rollup;
    }

    if (result.size() < max) {
      if (monitoringMessages.size() > 0) {
        result.add(metric.getValue(monitoringMessages.get(0)));
      } else {
        result.add(null);
      }
    }
    for (int i = 1; i < monitoringMessages.size() && result.size() < max; ++i) {
      long
          steps =
          (monitoringMessages.get(i).getWindow() - monitoringMessages.get(i - 1).getWindow())
          / rollup;
      for (int j = 0; j < steps - 1 && result.size() < max; ++j) {
        result.add(null);
      }
      if (result.size() < max) {
        result.add(metric.getValue(monitoringMessages.get(i)));
      }
    }
    if (monitoringMessages.size() > 0) {
      long lastTimeMs = monitoringMessages.get(monitoringMessages.size() - 1).getWindow();
      while (lastTimeMs < stopTimeMs && result.size() < max) {
        result.add(null);
        lastTimeMs += rollup;
      }
    }

    return result;
  }

  public static RangeRequest createMergedRangeRequest(
      MemberInfo memberInfo,
      RangeRequest rangeRequest,
      String defaultClientId,
      String defaultGroup
  ) {
    RangeRequest out = new RangeRequest(
        rangeRequest.clusterId,
        rangeRequest.getRollupAlignedStartTimeMs(),
        rangeRequest.getRollupAlignedStopTimeMs()
    );
    out.rollup = rangeRequest.rollup;
    out.clientId = Strings.emptyToNull(memberInfo.getClientId());
    if (out.clientId == null) {
      out.clientId = defaultClientId;
    }
    out.group = Strings.emptyToNull(memberInfo.getGroup());
    if (out.group == null) {
      out.group = defaultGroup;
    }
    out.topic = Strings.emptyToNull(memberInfo.getTopicPartition().getTopic());
    if (out.topic != null) {
      out.partition = memberInfo.getTopicPartition().getPartition();
    } else {
      out.topic = Strings.emptyToNull(memberInfo.getTopic());
    }
    return out;
  }
}
