// (Copyright) [2016 - 2016] Confluent, Inc.
package io.confluent.controlcenter.rest.res;

import com.fasterxml.jackson.annotation.JsonProperty;
import com.google.common.base.MoreObjects;

import java.util.ArrayList;
import java.util.List;
import java.util.Objects;

@JsonStandard
public class KafkaCluster {
  public final String clusterId;
  public final String displayName;
  public final List<String> zookeeperConnect;
  public final List<String> bootstrapServers;

  public KafkaCluster(String clusterId, String displayName) {
    this(clusterId, displayName, new ArrayList<String>(), new ArrayList<String>());
  }

  public KafkaCluster(
      @JsonProperty("clusterId") String clusterId,
      @JsonProperty("displayName") String displayName,
      @JsonProperty("zookeeperConnect") List<String> zookeeperConnect,
      @JsonProperty("bootstrapServers") List<String> bootstrapServers) {
    this.clusterId = clusterId;
    this.displayName = displayName;
    this.zookeeperConnect = zookeeperConnect;
    this.bootstrapServers = bootstrapServers;
  }

  @Override
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    KafkaCluster that = (KafkaCluster) o;
    return Objects.equals(clusterId, that.clusterId);
  }

  @Override
  public int hashCode() {
    return Objects.hash(clusterId);
  }

  @Override
  public String toString() {
    return MoreObjects.toStringHelper(this)
        .add("id", clusterId)
        .add("displayName", displayName)
        .add("zookeeper.connect", zookeeperConnect)
        .add("bootstrap.servers", bootstrapServers)
        .toString();
  }
}