// (Copyright) [2016 - 2016] Confluent, Inc.
package io.confluent.controlcenter.serialization;

import org.apache.kafka.common.serialization.Deserializer;
import org.apache.kafka.common.serialization.Serializer;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import java.util.Map;

import io.confluent.controlcenter.record.Controlcenter.VerifierInfo;
import io.confluent.controlcenter.streams.verify.MonitoringVerifier;
import io.confluent.serializers.ProtoSerde;

public class MonitoringVerifierSerialization
    implements Serializer<MonitoringVerifier>, Deserializer<MonitoringVerifier> {

  private static final Logger log = LoggerFactory.getLogger(MonitoringVerifierSerialization.class);

  private final ProtoSerde<VerifierInfo> serde = new ProtoSerde<>(VerifierInfo.getDefaultInstance()); //TODO: inject this

  @Override
  public void configure(Map<String, ?> configs, boolean isKey) {
    serde.configure(configs, isKey);
  }

  @Override
  public byte[] serialize(String topic, MonitoringVerifier data) {
    VerifierInfo info = toVerifierInfo(data);
    if (info == null) {
      return null;
    }
    return serde.serialize(topic, info);
  }

  @Override
  public MonitoringVerifier deserialize(String topic, byte[] data) {
    if (data == null) {
      return null;
    }

    VerifierInfo info = serde.deserialize(topic, data);
    MonitoringVerifier out = null;
    if (info != null) {
      try {
        out = new MonitoringVerifier(info);
      } catch (Exception e) {
        log.error("Constructing monitoring verifier from de-serialized verifier info", e);
      }
    }
    return out;
  }

  private VerifierInfo toVerifierInfo(MonitoringVerifier verifier) {
    if (verifier == null) {
      return null;
    }
    return verifier.createVerifierInfo();
  }

  public byte[] fromJSON(String json) {
    return serde.fromJSON(json);
  }

  public String toJSON(MonitoringVerifier data) {
    return serde.toJSON(toVerifierInfo(data));
  }

  @Override
  public void close() {
    serde.close();
  }
}
