// (Copyright) [2016 - 2016] Confluent, Inc.
package io.confluent.controlcenter.serialization;

import com.google.common.collect.ImmutableList;
import com.google.common.collect.ImmutableMap;
import io.confluent.controlcenter.keys.Keys.KeyType;
import io.confluent.monitoring.record.Monitoring.MonitoringMessage;
import io.confluent.serializers.OrderedKeyPrefixedProtoSerde;
import io.confluent.serializers.OrderedKeyPrefixedSerde;

import static io.confluent.controlcenter.keys.Keys.KeyType.EXPECTED_PRODUCTION;
import static io.confluent.controlcenter.keys.Keys.KeyType.EXPECTED_PRODUCTION_CLIENT;
import static io.confluent.controlcenter.keys.Keys.KeyType.EXPECTED_PRODUCTION_GROUP;
import static io.confluent.controlcenter.keys.Keys.KeyType.EXPECTED_PRODUCTION_GROUP_CLIENT_TOPIC_PARTITION;
import static io.confluent.controlcenter.keys.Keys.KeyType.EXPECTED_PRODUCTION_IN_TOPIC;
import static io.confluent.controlcenter.keys.Keys.KeyType.EXPECTED_PRODUCTION_IN_TOPICPARTITION_FOR_CLIENT;
import static io.confluent.controlcenter.keys.Keys.KeyType.EXPECTED_PRODUCTION_IN_TOPICPARTITION_FOR_GROUP;
import static io.confluent.controlcenter.keys.Keys.KeyType.INFO_CLIENTIDS_IN_GROUP;
import static io.confluent.controlcenter.keys.Keys.KeyType.INFO_GROUPS_IN_CLIENTTYPE;
import static io.confluent.controlcenter.keys.Keys.KeyType.INFO_TOPICPARTITIONS_IN_CLIENT;
import static io.confluent.controlcenter.keys.Keys.KeyType.INFO_TOPICPARTITIONS_IN_GROUP;
import static io.confluent.controlcenter.keys.Keys.KeyType.INFO_TOPICS_IN_CLIENTTYPE;
import static io.confluent.controlcenter.keys.Keys.KeyType.LOOKUP_CLIENTTYPE;
import static io.confluent.controlcenter.keys.Keys.KeyType.LOOKUP_CLIENTTYPE_CLIENT;
import static io.confluent.controlcenter.keys.Keys.KeyType.LOOKUP_CLIENTTYPE_CLIENT_TOPIC_PARTITION;
import static io.confluent.controlcenter.keys.Keys.KeyType.LOOKUP_CLIENTTYPE_GROUP;
import static io.confluent.controlcenter.keys.Keys.KeyType.LOOKUP_CLIENTTYPE_GROUP_TOPICPARTITION;
import static io.confluent.controlcenter.keys.Keys.KeyType.LOOKUP_CLIENTTYPE_TOPIC;
import static io.confluent.controlcenter.keys.Keys.KeyType.LOOKUP_CLIENTTYPE_TOPICPARTITION;

public class OrderedKeyPrefixedMMSerdeSupplier implements OrderedKeyPrefixedSerdeSupplier<KeyType, MonitoringMessage> {

  private static final ImmutableMap<KeyType, ImmutableList<Integer>> fieldIdMap = getFieldIdMap();

  @Override
  public OrderedKeyPrefixedSerde<KeyType, MonitoringMessage> get() {
    return OrderedKeyPrefixedProtoSerde.create(KeyType.UNRECOGNIZED, MonitoringMessage.getDefaultInstance(), fieldIdMap);
  }

  @Override
  public OrderedKeyPrefixedSerde<KeyType, MonitoringMessage> get(KeyType keyType) {
    return OrderedKeyPrefixedProtoSerde.create(keyType, MonitoringMessage.getDefaultInstance(), fieldIdMap);
  }

  private static ImmutableMap<KeyType, ImmutableList<Integer>> getFieldIdMap() {
    return ImmutableMap.<KeyType, ImmutableList<Integer>>builder()
        .put(INFO_CLIENTIDS_IN_GROUP,
            ImmutableList.of(
              MonitoringMessage.CLUSTERID_FIELD_NUMBER,
              MonitoringMessage.CLIENTTYPE_FIELD_NUMBER,
              MonitoringMessage.GROUP_FIELD_NUMBER
            ))
        .put(INFO_TOPICPARTITIONS_IN_CLIENT,
            ImmutableList.of(
              MonitoringMessage.CLUSTERID_FIELD_NUMBER,
              MonitoringMessage.CLIENTTYPE_FIELD_NUMBER,
              MonitoringMessage.CLIENTID_FIELD_NUMBER
            ))
        .put(INFO_GROUPS_IN_CLIENTTYPE,
            ImmutableList.of(
              MonitoringMessage.CLUSTERID_FIELD_NUMBER,
              MonitoringMessage.CLIENTTYPE_FIELD_NUMBER
            ))
        .put(INFO_TOPICS_IN_CLIENTTYPE,
            ImmutableList.of(
              MonitoringMessage.CLUSTERID_FIELD_NUMBER,
              MonitoringMessage.CLIENTTYPE_FIELD_NUMBER
            ))
        .put(INFO_TOPICPARTITIONS_IN_GROUP,
            ImmutableList.of(
              MonitoringMessage.CLUSTERID_FIELD_NUMBER,
              MonitoringMessage.CLIENTTYPE_FIELD_NUMBER,
              MonitoringMessage.GROUP_FIELD_NUMBER
            ))
        .put(LOOKUP_CLIENTTYPE,
            ImmutableList.of(
            MonitoringMessage.CLUSTERID_FIELD_NUMBER,
            MonitoringMessage.CLIENTTYPE_FIELD_NUMBER
            ))
        .put(EXPECTED_PRODUCTION,
            ImmutableList.of(
              MonitoringMessage.CLUSTERID_FIELD_NUMBER,
              MonitoringMessage.CLIENTTYPE_FIELD_NUMBER
            ))
        .put(EXPECTED_PRODUCTION_GROUP,
            ImmutableList.of(
              MonitoringMessage.CLUSTERID_FIELD_NUMBER,
              MonitoringMessage.CLIENTTYPE_FIELD_NUMBER,
              MonitoringMessage.GROUP_FIELD_NUMBER
            ))
        .put(EXPECTED_PRODUCTION_CLIENT,
            ImmutableList.of(
              MonitoringMessage.CLUSTERID_FIELD_NUMBER,
              MonitoringMessage.CLIENTTYPE_FIELD_NUMBER,
              MonitoringMessage.CLIENTID_FIELD_NUMBER
            ))
        .put(EXPECTED_PRODUCTION_GROUP_CLIENT_TOPIC_PARTITION,
            ImmutableList.of(
              MonitoringMessage.CLUSTERID_FIELD_NUMBER,
              MonitoringMessage.CLIENTTYPE_FIELD_NUMBER,
              MonitoringMessage.GROUP_FIELD_NUMBER,
              MonitoringMessage.CLIENTID_FIELD_NUMBER,
              MonitoringMessage.TOPIC_FIELD_NUMBER,
              MonitoringMessage.PARTITION_FIELD_NUMBER
            ))
        .put(LOOKUP_CLIENTTYPE_GROUP,
            ImmutableList.of(
              MonitoringMessage.CLUSTERID_FIELD_NUMBER,
              MonitoringMessage.CLIENTTYPE_FIELD_NUMBER,
              MonitoringMessage.GROUP_FIELD_NUMBER
            ))
        .put(LOOKUP_CLIENTTYPE_CLIENT_TOPIC_PARTITION,
            ImmutableList.of(
              MonitoringMessage.CLUSTERID_FIELD_NUMBER,
              MonitoringMessage.CLIENTTYPE_FIELD_NUMBER,
              MonitoringMessage.CLIENTID_FIELD_NUMBER,
              MonitoringMessage.TOPIC_FIELD_NUMBER,
              MonitoringMessage.PARTITION_FIELD_NUMBER
            ))
        .put(EXPECTED_PRODUCTION_IN_TOPIC,
            ImmutableList.of(
              MonitoringMessage.CLUSTERID_FIELD_NUMBER,
              MonitoringMessage.TOPIC_FIELD_NUMBER
            ))
        .put(EXPECTED_PRODUCTION_IN_TOPICPARTITION_FOR_GROUP,
            ImmutableList.of(
              MonitoringMessage.CLUSTERID_FIELD_NUMBER,
              MonitoringMessage.GROUP_FIELD_NUMBER,
              MonitoringMessage.TOPIC_FIELD_NUMBER,
              MonitoringMessage.PARTITION_FIELD_NUMBER
            ))
        .put(EXPECTED_PRODUCTION_IN_TOPICPARTITION_FOR_CLIENT,
            ImmutableList.of(
              MonitoringMessage.CLUSTERID_FIELD_NUMBER,
              MonitoringMessage.TOPIC_FIELD_NUMBER,
              MonitoringMessage.PARTITION_FIELD_NUMBER,
              MonitoringMessage.CLIENTID_FIELD_NUMBER
            ))
        .put(LOOKUP_CLIENTTYPE_TOPIC,
            ImmutableList.of(
              MonitoringMessage.CLUSTERID_FIELD_NUMBER,
              MonitoringMessage.CLIENTTYPE_FIELD_NUMBER,
              MonitoringMessage.TOPIC_FIELD_NUMBER
            ))
        .put(LOOKUP_CLIENTTYPE_TOPICPARTITION,
            ImmutableList.of(
              MonitoringMessage.CLUSTERID_FIELD_NUMBER,
              MonitoringMessage.CLIENTTYPE_FIELD_NUMBER,
              MonitoringMessage.TOPIC_FIELD_NUMBER,
              MonitoringMessage.PARTITION_FIELD_NUMBER
            ))
        .put(LOOKUP_CLIENTTYPE_GROUP_TOPICPARTITION,
            ImmutableList.of(
              MonitoringMessage.CLUSTERID_FIELD_NUMBER,
              MonitoringMessage.CLIENTTYPE_FIELD_NUMBER,
              MonitoringMessage.GROUP_FIELD_NUMBER,
              MonitoringMessage.TOPIC_FIELD_NUMBER,
              MonitoringMessage.PARTITION_FIELD_NUMBER
            ))
        .put(LOOKUP_CLIENTTYPE_CLIENT,
            ImmutableList.of(
              MonitoringMessage.CLUSTERID_FIELD_NUMBER,
              MonitoringMessage.CLIENTTYPE_FIELD_NUMBER,
              MonitoringMessage.CLIENTID_FIELD_NUMBER
        ))
        .build();
    }
}
