// (Copyright) [2016 - 2016] Confluent, Inc.
package io.confluent.controlcenter.streams.alert;

import com.google.inject.Inject;
import io.confluent.controlcenter.keys.Keys.KeyType;
import io.confluent.controlcenter.serialization.OrderedKeyPrefixedSerdeSupplier;
import io.confluent.monitoring.record.Monitoring.MonitoringMessage;
import io.confluent.serializers.OrderedKeyPrefixedSerde;
import org.apache.kafka.common.utils.Bytes;
import org.apache.kafka.streams.kstream.Predicate;
import org.apache.kafka.streams.kstream.Windowed;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

/**
 * Checks that an aggregate in a monitoring message is for a consumer group grouping.
 */
public class GroupMeasurement implements Predicate<Windowed<Bytes>, MonitoringMessage> {

  private static final Logger log = LoggerFactory.getLogger(GroupMeasurement.class);
  private final OrderedKeyPrefixedSerde<KeyType, MonitoringMessage> keySerde;

  @Inject
  public GroupMeasurement(OrderedKeyPrefixedSerdeSupplier<KeyType, MonitoringMessage> keySerdeSupplier) {
    this.keySerde = keySerdeSupplier.get();
  }

  @Override
  public boolean test(Windowed<Bytes> key, MonitoringMessage value) {
    KeyType keyType = keySerde.extractPrefix(key.key());
    return keyType.equals(KeyType.EXPECTED_PRODUCTION_GROUP) || keyType.equals(KeyType.LOOKUP_CLIENTTYPE_GROUP);
  }
}
