// (Copyright) [2016 - 2016] Confluent, Inc.
package io.confluent.controlcenter.streams.group;

import io.confluent.controlcenter.keys.Keys.KeyType;
import io.confluent.controlcenter.record.Controlcenter.MemberInfo;
import io.confluent.controlcenter.record.Controlcenter.TopicPartition;
import io.confluent.controlcenter.record.Controlcenter.WindowedGrouping;
import io.confluent.controlcenter.streams.TypeMapper;
import io.confluent.monitoring.record.Monitoring.MonitoringMessage;
import io.confluent.serializers.OrderedKeyPrefixedSerde;
import org.apache.kafka.common.utils.Bytes;
import org.apache.kafka.streams.KeyValue;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

public class WindowedGroupingTypeMapper implements TypeMapper<WindowedGrouping> {

  private static final Logger log = LoggerFactory.getLogger
      (WindowedGroupingTypeMapper.class);

  private final OrderedKeyPrefixedSerde<KeyType, MonitoringMessage> serde;

  public WindowedGroupingTypeMapper(OrderedKeyPrefixedSerde<KeyType, MonitoringMessage> serde) {
    this.serde = serde;
  }

  private MemberInfo selectMember(MonitoringMessage value) {
    MemberInfo.Builder mib = MemberInfo.newBuilder();
    switch (serde.prefix()) {
      case INFO_CLIENTIDS_IN_GROUP:
        mib.setClientId(value.getClientId());
        break;
      case INFO_GROUPS_IN_CLIENTTYPE:
        mib.setGroup(value.getGroup());
        break;
      case INFO_TOPICS_IN_CLIENTTYPE:
        mib.setTopic(value.getTopic());
        break;
      case INFO_TOPICPARTITIONS_IN_CLIENT:
      case INFO_TOPICPARTITIONS_IN_GROUP:
        mib.setTopicPartition(
            TopicPartition.newBuilder()
                .setTopic(value.getTopic())
                .setPartition(value.getPartition())
                .build()
        );
        break;
      default:
        log.error("invalid type={}", serde.prefix());
    }
    return mib.build();
  }

  @Override
  public KeyValue<Bytes, WindowedGrouping> apply(byte[] key, MonitoringMessage value) {
    WindowedGrouping cgi = WindowedGrouping.newBuilder()
        .setWindow(value.getWindow())
        .addMembers(selectMember(value))
        .build();
    return KeyValue.pair(serde.key(value), cgi);
  }
}
