// (Copyright) [2016 - 2016] Confluent, Inc.
package io.confluent.controlcenter.streams.monitoring;

import org.apache.kafka.streams.kstream.Aggregator;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import io.confluent.monitoring.record.Monitoring.MessageType;
import io.confluent.monitoring.record.Monitoring.MonitoringMessage;

public class MonitoringMessageAggregator<K>
    implements Aggregator<K, MonitoringMessage, MonitoringMessage> {

  private static final Logger log = LoggerFactory.getLogger(MonitoringMessageAggregator.class);

  private final boolean strip;

  public static <K> MonitoringMessageAggregator<K> stripped() {
    return new MonitoringMessageAggregator<>(true);
  }

  private MonitoringMessageAggregator(boolean strip) {
    this.strip = strip;
  }

  public MonitoringMessageAggregator() {
    this(false);
  }

  @Override
  public MonitoringMessage apply(
      K aggKey,
      MonitoringMessage value,
      MonitoringMessage aggregate
  ) {
    if (value == null) {
      log.warn("action=apply value=null aggKey={}", aggKey);
      return aggregate;
    }

    if (aggregate == null) {
      log.warn("action=apply aggregate=null aggKey={}", aggKey);
      return aggregate;
    }
    return aggregate(value, aggregate);
  }

  public MonitoringMessage aggregate(
      MonitoringMessage value,
      MonitoringMessage aggregate
  ) {
    MonitoringMessage.Builder builder = MonitoringMessage.newBuilder(aggregate)
        .setCount(aggregate.getCount() + value.getCount())
        .setAggregateBytes(aggregate.getAggregateBytes() + value.getAggregateBytes())
        .setAggregateCrc(aggregate.getAggregateCrc() ^ value.getAggregateCrc())
        .setTotalLatency(aggregate.getTotalLatency() + value.getTotalLatency())
        .setMinLatency(Math.min(aggregate.getMinLatency(), value.getMinLatency()))
        .setMaxLatency(Math.max(aggregate.getMaxLatency(), value.getMaxLatency()))
        .setType(value.getType() == MessageType.ERROR || aggregate.getType() == MessageType.ERROR ?
                 MessageType.ERROR : MessageType.NORMAL)
        .setClientType(value.getClientType())
        .setSequence(Math.max(aggregate.getSequence(), value.getSequence()) + 1)
        .setWindow(Math.max(value.getWindow(), aggregate.getWindow()))
        .setArrivalTime(Math.max(aggregate.getArrivalTime(), value.getArrivalTime()))
        .setPartition(value.getPartition())
        .setClientId(value.getClientId())
        .setTopic(value.getTopic())
        .setGroup(value.getGroup())
        .setSession(value.getSession());

    if (strip) {
      builder = builder
          .clearPartition()
          .clearClientId()
          .clearTopic()
          .clearSession();
    }

    return builder.build();
  }

}
