// (Copyright) [2016 - 2016] Confluent, Inc.
package io.confluent.controlcenter.util;

import com.google.common.collect.Lists;
import com.google.common.collect.Ordering;
import com.google.inject.Inject;
import io.confluent.controlcenter.rest.res.Topic;
import kafka.utils.ZkUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import scala.Option;
import scala.collection.Iterator;
import scala.collection.Seq;

import java.util.List;

public class ZKKafkaMetadataClient implements KafkaClusterMetadataClient {
  private static final Logger log = LoggerFactory.getLogger(new Object() {}.getClass().getEnclosingClass());
  private final ZKUtilsFactory zkUtilsFactory;
  private final String zookeeperConnect;

  @Inject
  public ZKKafkaMetadataClient(
      String zookeeperConnect,
      ZKUtilsFactory zkUtilsFactory
  ) {
    this.zookeeperConnect = zookeeperConnect;
    this.zkUtilsFactory = zkUtilsFactory;
  }

  @Override
  public String queryClusterId() {
    ZkUtils zkUtils = zkUtilsFactory.create(zookeeperConnect);
    try {
      Option<String> clusterIdOpt = zkUtils.getClusterId();
      if (clusterIdOpt.isEmpty()) {
        return null;
      }
      return zkUtils.getClusterId().get();
    } finally {
      zkUtils.close();
    }
  }

  @Override
  public List<Topic> queryTopics() {
    ZkUtils zkUtils = zkUtilsFactory.create(zookeeperConnect);
    try {
      List<Topic> out = Lists.newArrayList();
      Seq<String> topics = zkUtils.getAllTopics();
      for (Iterator<String> i = topics.iterator(); i.hasNext(); ) {
        out.add(new Topic(i.next()));
      }
      return Ordering.natural().immutableSortedCopy(out);
    } catch (Throwable t) {
      log.error("Error getting topics from ZooKeeper cluster {}", zookeeperConnect, t);
      throw t;
    } finally {
      zkUtils.close();
    }
  }
}
