// (Copyright) [2016 - 2016] Confluent, Inc.
package io.confluent.controlcenter.data;

import io.confluent.command.cluster_metadata.CommandClusterMetadata;
import io.confluent.command.record.Command;
import io.confluent.command.record.Command.CommandKey;
import io.confluent.command.record.Command.CommandMessage;
import io.confluent.controlcenter.rest.res.Topic;
import io.confluent.controlcenter.streams.MockReadOnlyKeyValueStore;
import io.confluent.controlcenter.util.KafkaClusterMetadataClient;
import io.confluent.controlcenter.util.KafkaClusterMetadataClientFactory;
import org.easymock.EasyMock;
import org.junit.Before;
import org.junit.Test;

import java.util.Arrays;
import java.util.List;

import static org.easymock.EasyMock.createMock;
import static org.easymock.EasyMock.eq;
import static org.easymock.EasyMock.expect;
import static org.easymock.EasyMock.replay;
import static org.junit.Assert.*;

public class KafkaMetadataDaoTest {
  private MockReadOnlyKeyValueStore<CommandKey, CommandMessage> clusterMetaDataStore;
  private KafkaMetadataDao dao;
  private KafkaClusterMetadataClient mockClient;
  private KafkaClusterMetadataClientFactory mockClientFactory;

  @Before
  public void setUp() throws Exception {
    clusterMetaDataStore = new MockReadOnlyKeyValueStore<>();
    MockReadOnlyKeyValueStore.mockAddKafkaClusterMetadata(
        clusterMetaDataStore,
        "xxxxx",
        "My Xy Kafka Cluster",
        CommandClusterMetadata.KafkaClusterMetadata.newBuilder()
            .addAllZookeeperConnect(Arrays.asList("zk1", "zk2"))
            .addAllBootstrapServers(Arrays.asList("k1", "k2", "k3"))
            .build()
    );
    mockClient = createMock(KafkaClusterMetadataClient.class);
    mockClientFactory = createMock(KafkaClusterMetadataClientFactory.class);
    dao = new KafkaMetadataDao(mockClientFactory, clusterMetaDataStore);
  }

  @Test
  public void getTopics() throws Exception {
    List<Topic> allTopics = Arrays.asList(new Topic("foo"), new Topic("__consumer_offsets"), new Topic("bar"));
    expect(mockClientFactory.create(eq("zk1,zk2"))).andReturn(mockClient).once();
    expect(mockClient.queryTopics()).andReturn(allTopics);
    replay(mockClientFactory);
    replay(mockClient);

    List<Topic> topics = dao.getTopics("xxxxx", true);
    assertEquals(Arrays.asList(new Topic("foo"), new Topic("bar")), topics);
  }

}