// (Copyright) [2016 - 2016] Confluent, Inc.
package io.confluent.controlcenter.serialization;

import io.confluent.controlcenter.streams.verify.MonitoringVerifier;
import io.confluent.monitoring.common.MonitoringMessageUtil;
import io.confluent.monitoring.record.Monitoring.ClientType;
import io.confluent.monitoring.record.Monitoring.MonitoringMessage;
import org.apache.kafka.common.errors.SerializationException;
import org.junit.Before;
import org.junit.Test;

import static org.junit.Assert.assertNull;
import static org.junit.Assert.assertTrue;

public class MonitoringVerifierSerializationTest {

  private MonitoringVerifierSerialization serde;
  private MonitoringMessage monitoringMessage;

  @Before
  public void setUp() throws Exception {
    serde = new MonitoringVerifierSerialization();
    serde.configure(null, false);

    monitoringMessage = MonitoringMessage.newBuilder(MonitoringMessageUtil.baseMonitoringMessage())
        .setSession("test-session")
        .setGroup("test-group")
        .setClientId("test-client")
        .setClientType(ClientType.PRODUCER)
        .setTopic("test-topic")
        .setPartition(0)
        .build();
  }

  @Test
  public void testSerializeDeserialize() {
    MonitoringVerifier verifier = new MonitoringVerifier(monitoringMessage, 1000, 5);
    MonitoringVerifier verifierOut = serde.deserialize("topic", serde.serialize("topic", verifier));
    assertTrue(verifier.equals(verifierOut));
    serde.close();
  }

  @Test
  public void testSerializeNull() {
    assertNull(serde.serialize("topic", null));
  }

  @Test
  public void testDeserializeNull() {
    assertNull(serde.deserialize("topic", null));
  }

  @Test(expected = SerializationException.class)
  public void testDeserializeGarbageData() {
    byte[] bytes = "some string".getBytes();
    MonitoringVerifier mv = serde.deserialize("topic", bytes);
  }
}
