// (Copyright) [2016 - 2016] Confluent, Inc.
package io.confluent.controlcenter.serialization;

import io.confluent.command.CommandStore;
import io.confluent.command.cluster_metadata.CommandClusterMetadata;
import io.confluent.command.cluster_metadata.CommandClusterMetadata.ClusterMetadata;
import io.confluent.command.record.Command;
import io.confluent.command.record.Command.CommandConfigType;
import io.confluent.command.record.Command.CommandKey;
import io.confluent.command.record.Command.CommandMessage;
import io.confluent.controlcenter.rest.res.KafkaCluster;
import io.confluent.monitoring.record.Monitoring;
import io.confluent.monitoring.record.Monitoring.MonitoringMessage;
import io.confluent.serializers.ProtoSerde;
import io.confluent.serializers.UberSerde;
import org.apache.kafka.clients.consumer.ConsumerRecord;
import org.apache.kafka.common.record.TimestampType;
import org.junit.Before;
import org.junit.Test;

import java.io.ByteArrayOutputStream;
import java.io.PrintStream;
import java.nio.charset.StandardCharsets;
import java.util.Properties;

import static org.junit.Assert.*;

public class UberFormatterTest {
  private UberFormatter formatter;


  @Before
  public void setUp() {
    Properties props = new Properties();
    props.setProperty("print.timestamp", "false");
    formatter = new UberFormatter();
    formatter.init(props);
  }


  @Test
  public void writeTo() throws Exception {
    MonitoringMessage monMsg = MonitoringMessage.newBuilder()
        .setClientId("fakeClientId")
        .setTopic("test-topic")
        .setPartition(2)
        .build();
    UberSerde<MonitoringMessage> serde = new ProtoSerde<>(MonitoringMessage.getDefaultInstance());
    byte[] valBytes = serde.serialize(monMsg);
    ConsumerRecord<byte[], byte[]> record = new ConsumerRecord<>("_confluent-monitoring", 3, 55L, null, valBytes);
    ByteArrayOutputStream outStream = new ByteArrayOutputStream();
    PrintStream printStream = new PrintStream(outStream);
    formatter.writeTo(record, printStream);
    String output = new String(outStream.toByteArray(), StandardCharsets.UTF_8);
    assertEquals("_confluent-monitoring\t3\tnull\t{\"clientType\":\"CONSUMER\",\"clientId\":\"fakeClientId\",\"group\":\"\",\"session\":\"\",\"sequence\":\"0\",\"window\":\"0\",\"timestamp\":\"0\",\"topic\":\"test-topic\",\"partition\":2,\"count\":\"0\",\"aggregateBytes\":\"0\",\"aggregateCrc\":0,\"totalLatency\":\"0\",\"minLatency\":\"0\",\"maxLatency\":\"0\",\"samplePeriod\":\"0\",\"type\":\"NORMAL\",\"shutdown\":false,\"minWindow\":\"0\",\"maxWindow\":\"0\",\"monitoringTopicPartition\":0,\"clusterId\":\"\",\"clusterName\":\"\",\"arrivalTime\":\"0\"}\n", output);
  }

  @Test
  public void writeToCmdTopic() throws Exception {
    CommandKey key = CommandKey.newBuilder()
        .setConfigType(CommandConfigType.CLUSTER_METADATA)
        .setGuid("xxxxx")
        .build();
    CommandMessage msg = CommandMessage.newBuilder()
        .setClusterMetadata(ClusterMetadata.newBuilder()
            .setDisplayName("Funky Cluster")
        )
        .build();
    UberSerde<CommandKey> keySerde = CommandStore.getCommandKeySerde();
    UberSerde<CommandMessage> valSerde = CommandStore.getCommandMessageSerde();


    ConsumerRecord<byte[], byte[]> record = new ConsumerRecord<>("_confluent-command", 3, 55L, keySerde.serialize(key), valSerde.serialize(msg));
    ByteArrayOutputStream outStream = new ByteArrayOutputStream();
    PrintStream printStream = new PrintStream(outStream);
    formatter.writeTo(record, printStream);
    String output = new String(outStream.toByteArray(), StandardCharsets.UTF_8);
    assertEquals("_confluent-command\t3\t{\"configType\":\"CLUSTER_METADATA\",\"guid\":\"xxxxx\"}\t{\"clusterMetadata\":{\"displayName\":\"Funky Cluster\"}}\n", output);
  }

}
