// (Copyright) [2016 - 2016] Confluent, Inc.
package io.confluent.controlcenter.streams;

import com.google.common.collect.Maps;

import org.apache.kafka.common.metrics.Sensor;
import org.apache.kafka.common.serialization.Serde;
import org.apache.kafka.streams.StreamsMetrics;
import org.apache.kafka.streams.processor.ProcessorContext;
import org.apache.kafka.streams.processor.StateRestoreCallback;
import org.apache.kafka.streams.processor.StateStore;
import org.apache.kafka.streams.processor.TaskId;
import org.apache.kafka.streams.processor.internals.RecordCollector;

import java.io.File;
import java.util.HashMap;
import java.util.Map;

/**
 * Mock processor which manages kv stores only (for now, but we can make it more powerful).
 */
public class MockProcessorContext implements ProcessorContext, RecordCollector.Supplier {
  private Map<String, StateStore> storeMap = new HashMap<>();

  private final RecordCollector.Supplier recordCollectorSupplier;
  private File stateDir = null;

  public MockProcessorContext(File stateDir, final RecordCollector collector) {
    recordCollectorSupplier = new RecordCollector.Supplier() {
      @Override
      public RecordCollector recordCollector() {
        return collector;
      }
    };
    this.stateDir = stateDir;
  }

  @Override
  public RecordCollector recordCollector() {
    return recordCollectorSupplier.recordCollector();
  }

  @Override
  public TaskId taskId() {
    return new TaskId(0, 0);
  }

  @Override
  public String applicationId() {
    return "mockApplication";
  }

  @Override
  public Serde<?> keySerde() {
    return null;
  }

  @Override
  public Serde<?> valueSerde() {
    return null;
  }

  @Override
  public File stateDir() {
    return stateDir;
  }

  @Override
  public StreamsMetrics metrics() {
    return new StreamsMetrics() {
      @Override
      public Sensor addLatencySensor(String scopeName, String entityName, String operationName, String... tags) {
        return null;
      }
      @Override
      public void recordLatency(Sensor sensor, long startNs, long endNs) {
      }
    };
  }

  @Override
  public void register(StateStore store, boolean loggingEnabled, StateRestoreCallback func) {
    storeMap.put(store.name(), store);
  }

  @Override
  public StateStore getStateStore(String name) {
    return storeMap.get(name);
  }

  @Override
  public void schedule(long interval) {
  }

  @Override
  @SuppressWarnings("unchecked")
  public <K, V> void forward(K key, V value) {
  }

  @Override
  @SuppressWarnings("unchecked")
  public <K, V> void forward(K key, V value, int childIndex) {
  }

  @Override
  @SuppressWarnings("unchecked")
  public <K, V> void forward(K key, V value, String childName) {
  }

  @Override
  public void commit() {
    throw new UnsupportedOperationException("commit() not supported.");
  }

  @Override
  public String topic() {
    throw new UnsupportedOperationException("topic() not supported.");
  }

  @Override
  public int partition() {
    return 0;
  }

  @Override
  public long offset() {
    return 1;
  }

  @Override
  public long timestamp() {
    return 0;
  }

  @Override
  public Map<String, Object> appConfigs() {
    return Maps.newHashMap();
  }

  @Override
  public Map<String, Object> appConfigsWithPrefix(String s) {
    return Maps.newHashMap();
  }

}
