// (Copyright) [2016 - 2016] Confluent, Inc.
package io.confluent.controlcenter.streams;

import org.apache.kafka.clients.consumer.ConsumerRecord;
import org.apache.kafka.common.record.TimestampType;
import org.junit.Test;

import io.confluent.monitoring.record.Monitoring.MonitoringMessage;

import static org.junit.Assert.assertEquals;

public class WindowExtractorTest {

  private static final String KEY = "this doesnt matter";
  public static final String TOPIC = "fake topic";

  private static final MonitoringMessage makeMonitoringMessage(Long window) {
    return MonitoringMessage.newBuilder()
        .setWindow(window)
        .build();
  }

  @Test
  public void testWindowExtraction() {
    Long window = 10l;

    MonitoringMessage monitoringMessage = makeMonitoringMessage(window);
    WindowExtractor extractor = new WindowExtractor();
    Long
        extracted =
        extractor.extract(
            new ConsumerRecord<Object, Object>(TOPIC, 0, 1l, 0, TimestampType.CREATE_TIME, 0, 0, 0,
                                               KEY, monitoringMessage));

    assertEquals(window, extracted);
  }

  @Test
  public void testMissingValue() {
    WindowExtractor extractor = new WindowExtractor();
    Long
        extracted =
        extractor.extract(
            new ConsumerRecord<Object, Object>(TOPIC, 0, 1l, 0, TimestampType.CREATE_TIME, 0, 0,
                                               0, KEY, null));

    assertEquals(extracted.longValue(), 0l);
  }

  @Test
  public void testValueWithWrongType() {
    WindowExtractor extractor = new WindowExtractor();
    Long
        extracted =
        extractor.extract(
            new ConsumerRecord<Object, Object>(TOPIC, 0, 1l, 0, TimestampType.CREATE_TIME, 0, 0, 0,
                                               KEY, "value"));

    assertEquals(extracted.longValue(), 0l);
  }
}
