package io.confluent.controlcenter.streams.alert;

import io.confluent.controlcenter.keys.Keys.KeyType;
import io.confluent.controlcenter.serialization.OrderedKeyPrefixedMMSerdeSupplier;
import io.confluent.controlcenter.serialization.OrderedKeyPrefixedSerdeSupplier;
import io.confluent.monitoring.common.MonitoringMessageUtil;
import io.confluent.monitoring.record.Monitoring.ClientType;
import io.confluent.monitoring.record.Monitoring.MonitoringMessage;
import io.confluent.serializers.OrderedKeyPrefixedSerde;
import org.apache.kafka.streams.kstream.Windowed;
import org.apache.kafka.streams.kstream.internals.TimeWindow;
import org.junit.Test;

import static org.junit.Assert.assertFalse;
import static org.junit.Assert.assertTrue;

public class GroupMeasurementTest {

  private final OrderedKeyPrefixedSerdeSupplier<KeyType, MonitoringMessage> supplier = new OrderedKeyPrefixedMMSerdeSupplier();

  private static final MonitoringMessage makeMonitoringMessage(ClientType clientType) {
    return MonitoringMessage.newBuilder(MonitoringMessageUtil.baseMonitoringMessage())
        .setClusterId("xxx-cluster-test")
        .setSession("test-session")
        .setGroup("test-group")
        .setClientId("test-client")
        .setClientType(clientType)
        .setTopic("test-topic")
        .setPartition(0)
        .build();
  }

  @Test
  public void testBasicGroupMeasurementConsumerGroup() {
    OrderedKeyPrefixedSerde<KeyType, MonitoringMessage> keySerde = supplier.get(KeyType.LOOKUP_CLIENTTYPE_GROUP);
    GroupMeasurement gm = new GroupMeasurement(supplier);
    MonitoringMessage msg = makeMonitoringMessage(ClientType.CONSUMER);
    assertTrue(gm.test(new Windowed<>(keySerde.key(msg), new TimeWindow(0, 1000)), msg));
  }

  @Test
  public void testBasicGroupMeasurementExpectedProductionGroup() {
    OrderedKeyPrefixedSerde<KeyType, MonitoringMessage> keySerde = supplier.get(KeyType.EXPECTED_PRODUCTION_GROUP);
    GroupMeasurement gm = new GroupMeasurement(supplier);
    MonitoringMessage msg = makeMonitoringMessage(ClientType.PRODUCER);
    assertTrue(gm.test(new Windowed<>(keySerde.key(msg), new TimeWindow(0, 1000)), msg));
  }

  @Test
  public void testBasicGroupMeasurementExpectedProductionGroupClientTp() {
    OrderedKeyPrefixedSerde<KeyType, MonitoringMessage> keySerde = supplier.get(KeyType.EXPECTED_PRODUCTION_GROUP_CLIENT_TOPIC_PARTITION);
    GroupMeasurement gm = new GroupMeasurement(supplier);
    MonitoringMessage msg = makeMonitoringMessage(ClientType.PRODUCER);
    assertFalse(gm.test(new Windowed<>(keySerde.key(msg), new TimeWindow(0, 1000)), msg));
  }

  @Test
  public void testBasicGroupMeasurementExpectedProductionClient() {
    OrderedKeyPrefixedSerde<KeyType, MonitoringMessage> keySerde = supplier.get(KeyType.EXPECTED_PRODUCTION_CLIENT);
    GroupMeasurement gm = new GroupMeasurement(supplier);
    MonitoringMessage msg = makeMonitoringMessage(ClientType.PRODUCER);
    assertFalse(gm.test(new Windowed<>(keySerde.key(msg), new TimeWindow(0, 1000)), msg));
  }

  @Test
  public void testBasicGroupMeasurementConsumerGroupTp() {
    OrderedKeyPrefixedSerde<KeyType, MonitoringMessage> keySerde = supplier.get(KeyType.LOOKUP_CLIENTTYPE_GROUP_TOPICPARTITION);
    GroupMeasurement gm = new GroupMeasurement(supplier);
    MonitoringMessage msg = makeMonitoringMessage(ClientType.CONSUMER);
    assertFalse(gm.test(new Windowed<>(keySerde.key(msg), new TimeWindow(0, 1000)), msg));
  }
}
