// (Copyright) [2016 - 2016] Confluent, Inc.
package io.confluent.controlcenter.streams.cluster;

import io.confluent.controlcenter.record.Controlcenter.Cluster;
import io.confluent.controlcenter.record.Controlcenter.ClusterType;
import org.junit.Test;

import static org.junit.Assert.assertEquals;

public class ClusterAggregatorTest {
  private static final ClusterType CLUSTER_TYPE = ClusterType.KAFKA;
  private static final String CLUSTER_ID = "xxx-yyy";
  private static final ClusterAggregator clusterAggregator = new ClusterAggregator();

  private Cluster.Builder getBaseCluster() {
    return Cluster.newBuilder()
        .setClusterType(CLUSTER_TYPE)
        .setClusterId(CLUSTER_ID);
  }

  @Test
  public void testNewClusterNamesAreSet() throws Exception {
    Cluster aggEmpty = getBaseCluster().build();
    Cluster clusterWithNames = getBaseCluster()
        .setClusterName("us-west")
        .build();
    //Adding a record with name set to one where it's not set
    Cluster newAgg = clusterAggregator.apply(null, aggEmpty, clusterWithNames);
    assertEquals(CLUSTER_TYPE, newAgg.getClusterType());
    assertEquals(CLUSTER_ID, newAgg.getClusterId());
    assertEquals("us-west", newAgg.getClusterName());

    //Adding a record with name set to one where it's already set to something else
    Cluster aggNotEmpty = getBaseCluster()
        .setClusterName("replace-me")
        .build();
    Cluster newAgg2 = clusterAggregator.apply(null, aggNotEmpty, clusterWithNames);
    assertEquals(CLUSTER_TYPE, newAgg2.getClusterType());
    assertEquals(CLUSTER_ID, newAgg2.getClusterId());
    assertEquals("us-west", newAgg2.getClusterName());
  }

  @Test
  public void testEmptyNamesAreNotSet() throws Exception {
    Cluster aggNotEmpty = getBaseCluster()
        .setClusterName("do-not-replace-me")
        .build();
    Cluster clusterEmpty = getBaseCluster().build();
    //Combining a record with empty name and a record with non-empty name
    Cluster newAgg = clusterAggregator.apply(null, aggNotEmpty, clusterEmpty);
    assertEquals(CLUSTER_TYPE, newAgg.getClusterType());
    assertEquals(CLUSTER_ID, newAgg.getClusterId());
    assertEquals("do-not-replace-me", newAgg.getClusterName());
  }

}