// (Copyright) [2016 - 2016] Confluent, Inc.
package io.confluent.controlcenter.streams.monitoring;

import io.confluent.controlcenter.keys.Keys.KeyType;
import io.confluent.controlcenter.serialization.OrderedKeyPrefixedMMSerdeSupplier;
import io.confluent.controlcenter.serialization.OrderedKeyPrefixedSerdeSupplier;
import io.confluent.monitoring.common.MonitoringMessageUtil;
import io.confluent.monitoring.record.Monitoring.ClientType;
import io.confluent.monitoring.record.Monitoring.MonitoringMessage;
import io.confluent.serializers.OrderedKeyPrefixedSerde;
import org.apache.kafka.common.utils.Bytes;
import org.apache.kafka.streams.KeyValue;
import org.junit.Test;

import static org.junit.Assert.assertEquals;
import static org.junit.Assert.assertNotNull;

public class TypeMapperTest {

  private static final String CLUSTER_ID = "xxx-cluster-1";
  private static final String TOPIC = "topic";
  private static final String CLIENT = "client";
  private static final String GROUP = "group";
  private static final Integer PARTITION = 28980;

  @Test
  public void testMapping() {
    OrderedKeyPrefixedSerdeSupplier<KeyType, MonitoringMessage> supplier = new OrderedKeyPrefixedMMSerdeSupplier();
    for (KeyType keyType : KeyType.values()) {
      if (!keyType.equals(KeyType.UNRECOGNIZED)) {
        OrderedKeyPrefixedSerde<KeyType, MonitoringMessage> serde = supplier.get(keyType);
        MonitoringMessageTypeMapper typeMapper = new MonitoringMessageTypeMapper(serde);
        KeyValue<Bytes, MonitoringMessage> kv = typeMapper.apply(null, getMonitoringMessage());
        assertNotNull(kv);
        assertEquals(serde.key(getMonitoringMessage()), kv.key);
        MonitoringMessage keyMM = serde.toProto(kv.key);
        assertEquals(CLUSTER_ID, keyMM.getClusterId()); //All keys must set clusterId
      }
    }
  }

  private MonitoringMessage getMonitoringMessage() {
    return MonitoringMessage.newBuilder(MonitoringMessageUtil.baseMonitoringMessage())
        .setClusterId(CLUSTER_ID)
        .setClientType(ClientType.CONSUMER)
        .setTopic(TOPIC)
        .setClientId(CLIENT)
        .setGroup(GROUP)
        .setPartition(PARTITION)
        .build();
  }
}
