## Initial Setup ##

*Note!* All directions assume you have a similar file structure for your projects and that you're starting at the root:
``` bash
. # root
├── controlcenter
├── kafka
├── service-discovery-client
```

First you'll need to build a service-discovery-client source distribution.

``` bash
brew install python
git clone git@github.com:confluentinc/service-discovery-client.git
cd service-discovery-client
pip install -U --editable .
python setup.py sdist
```

Build a Kafka release tarball

``` bash
cd kafka
./gradlew releaseTarGz
```

Build Control Center

``` bash
cd controlcenter
mvn package -DskipTests
```

Install docker-machine and create default instance

``` bash
brew install docker-machine
docker-machine create -d virtualbox --virtualbox-memory 4096 default
```

## Build Docker Images ##

``` bash
eval "$(docker-machine env default)"
cd controlcenter/docker/images
./build-all
```

## Run Locally ##

``` bash
eval "$(docker-machine env default)"
./start-all

docker ps
docker logs -f control-center
#Consul UI
open http://$(docker-machine ip):8500
#C3 UI
open http://$(docker-machine ip):9021
```

## Push Images to AWS Container Registry ##

``` bash
eval "$(docker-machine env default)"
./push-all
```

## Cleaning Up DiskSpace ##

Every so often, you'll fill up your boot2docker disk space.  You can clean it up with tips from [here](http://blog.benhall.me.uk/2015/01/boot2docker-runs-disk-space/).

``` bash
#Remove exited containers
docker ps -a -q | xargs -n 1 -I {} docker rm {}
#Remove untagged images
docker rmi $( docker images | grep '<none>' | tr -s ' ' | cut -d ' ' -f 3)
```
