// (Copyright) [2016 - 2016] Confluent, Inc.
module.exports = {
  env: {
    browser: true,
    es6: true,
    node: true
  },
  extends: [
    'eslint:recommended',
    'plugin:react/recommended'
  ],
  parser: 'babel-eslint',
  parserOptions: {
    experimentalObjectRestSpread: true,
    ecmaVersion: 6,
    sourceType: 'module',
    ecmaFeatures: {
      jsx: true
    }
  },
  plugins: [
    'flowtype',
    'import',
    'mocha',
    'react'
  ],
  settings: {
    flowtype: {
      onlyFilesWithFlowAnnotation: true
    },
    'import/ignore': [
      '\.(less|css)$',
      '\.(svg|png|jpg|gif)$',
      '\.json$'
    ]
  },
  globals: {
    __DEV__: false,
    __PROD__: false,
    __TEST__: false,
    __USE_REDBOX__: false,
    __VERSION__: false
  },
  rules: {
    'array-bracket-spacing': [2, 'never'],
    'block-spacing': [2, 'always'],
    'brace-style': [2, '1tbs', { allowSingleLine: true }],
    camelcase: [2, { properties: 'never' }],
    'computed-property-spacing': [2, 'never'],
    'comma-dangle': [2, 'never'],
    'comma-spacing': 2,
    'eol-last': 2,
    eqeqeq: [2, 'smart'],
    'flowtype/define-flow-type': 2,
    'flowtype/generic-spacing': 2,
    'flowtype/require-parameter-type': 0,
    'flowtype/require-return-type': 0,
    'flowtype/require-valid-file-annotation': 2,
    'flowtype/space-after-type-colon': 2,
    'flowtype/space-before-generic-bracket': 2,
    'flowtype/space-before-type-colon': 2,
    'flowtype/type-id-match': 0,
    'flowtype/union-intersection-spacing': 2,
    'flowtype/use-flow-type': 2,
    'flowtype/valid-syntax': 2,
    'generator-star-spacing': [2, { before: false, after: true }],
    'yield-star-spacing': [2, { before: false, after: true }],
    'id-length': [2, { min: 2, max: 68, properties: 'never', exceptions: ['e', 'i', 'j', 'k', 'x', 'y', '_'] }],
    indent: [0, 2, { SwitchCase: 1 }], // useful once ternary operator works
    // 'import/no-unresolved': 2, // requires the (webpack) resolver to work properly but ran into some problems. flow should handle this already tho
    // 'import/named': 2, // this doesn't seem to work. probably needs resolver?
    'import/namespace': 2,
    'import/default': 0,
    'import/no-restricted-paths': 0,
    'import/export': 2,
    // 'import/no-named-as-default': 2, // potentially useful someday
    'import/no-named-as-default-member': 1,
    'import/no-deprecated': 2,
    // 'import/no-extraneous-dependencies': 2, // could be useful, but it needs to be aware of webpack root resolving
    'import/no-mutable-exports': 0, // covered by prefer-const
    'import/no-commonjs': 0,
    'import/no-amd': 0,
    'import/no-nodejs-modules': 0,
    'import/imports-first': 1,
    'import/no-duplicates': 1,
    'import/no-namespace': 0,
    'import/extensions': [1, {
      css: 'always',
      js: 'never',
      json: 'always',
      jsx: 'never',
      less: 'always',
      png: 'always',
      svg: 'always'
    }],
    'import/order': 0, // might be cool if it can figure out internal vs external vs type
    'import/newline-after-import': 1,
    'import/prefer-default-export': 0,
    'jsx-quotes': [2, 'prefer-double'],
    'key-spacing': 2,
    'keyword-spacing': 2,
    'lines-around-comment': 2,
    'mocha/no-exclusive-tests': 2,
    'no-case-declarations': 0,
    'no-extra-bind': 2,
    'no-extra-parens': [2, 'functions'],
    'no-extra-semi': 2,
    'no-implicit-coercion': 2,
    'no-loop-func': 2,
    'linebreak-style': [2, 'unix'],
    'no-mixed-spaces-and-tabs': 2,
    'no-magic-numbers': 0,
    'no-multi-spaces': 2,
    'no-multiple-empty-lines': 2,
    'no-param-reassign': [2, { props: false }],
    'padded-blocks': 0,
    'space-unary-ops': [2, { words: true, nonwords: false }],
    'no-whitespace-before-property': 2,
    'object-curly-newline': [0, { multiline: true, minProperties: 4 }],
    'no-trailing-spaces': 2,
    'no-unused-vars': 2,
    'no-var': 2,
    'object-curly-spacing': [2, 'always'],
    'operator-linebreak': 0,
    'one-var': [2, 'never'],
    'prefer-arrow-callback': 2,
    'prefer-const': 2,
    'no-useless-rename': 2,
    'prefer-rest-params': 2,
    'prefer-spread': 2,
    'prefer-template': 2,
    'quote-props': [2, 'as-needed'],
    quotes: [2, 'single', 'avoid-escape'],
    radix: 2,
    'template-curly-spacing': 2,
    'rest-spread-spacing': [2, 'never'],
    'react/jsx-boolean-value': [2, 'always'],
    'react/jsx-closing-bracket-location': 2,
    'react/jsx-curly-spacing': 2,
    'react/jsx-equals-spacing': 2,
    'react/jsx-handler-names': 1,
    'react/jsx-indent': [0, 2], // useful once ternary operator works
    'react/jsx-indent-props': [0, 2],  // useful once ternary operator works
    'react/jsx-key': 2,
    'react/jsx-max-props-per-line': [0, { maximum: 2 }],
    // lets enable this at some point - it actually has perf implications and is easy to fix
    // 'react/jsx-no-bind': [1, {
    //   allowArrowFunctions: true,
    //   allowBind: false,
    //   ignoreRefs: false
    // }],
    'react/jsx-no-literals': 0,
    'react/jsx-no-target-blank': 2,
    'react/jsx-pascal-case': 2,
    'react/jsx-space-before-closing': 2,
    'react/no-danger': 2,
    // 'react/prefer-stateless-function': 1, // lets enable this at some point
    'react/no-danger-with-children': 2,
    'react/no-did-mount-set-state': 2,
    'react/no-did-update-set-state': 2,
    'react/no-string-refs': 2,
    'react/prefer-es6-class': 2,
    'react/prop-types': 0, // overrides recommended
    'react/require-extension': 0,
    'react/self-closing-comp': 2,
    'react/jsx-wrap-multilines': 2,
    'space-infix-ops': 0,
    'unicode-bom': 2,
    'arrow-spacing': 2,
    'react/sort-comp': [2, {
      order: [
        'config',
        'everything-else',
        'lifecycle',
        'render'
      ],
      groups: {
        config: [
          'props',
          'state'
        ],
        lifecycle: [
          'componentWillMount',
          'componentDidMount',
          'componentWillReceiveProps',
          'shouldComponentUpdate',
          'componentWillUpdate',
          'componentDidUpdate',
          'componentWillUnmount'
        ]
      }
    }],
    semi: [2, 'always'],
    'semi-spacing': 2,
    'sort-imports': 0,
    'spaced-comment': 2,
    'no-spaced-func': 2,
    'space-before-blocks': [2, 'always'],
    'space-before-function-paren': [2, { anonymous: 'always', named: 'never' }],
    'space-in-parens': 2,
    strict: 0,
    'valid-jsdoc': 2,
    'valid-typeof': 2,
    yoda: 2
  }
};
