// @flow
// (Copyright) [2016 - 2016] Confluent, Inc.
import debug from 'debug';
import {
  getJson,
  makeAction
} from './util';

import type {
  Action,
  Dispatchable,
  Dispatcher
} from 'types';
import type { AuthState } from 'types/auth';

const log = debug('controlcenter:actions:auth');

export const RECEIVE_AUTH_DATA = 'RECEIVE_AUTH_DATA';
export type ReceiveAuthDataAction = Action<'RECEIVE_AUTH_DATA', AuthState>

export function loadAuthData(): Dispatchable {
  return (dispatch: Dispatcher) => {
    const reqPath = '/2.0/auth/principal';
    return getJson(reqPath)
      .then(data => {
        dispatch(makeAction(RECEIVE_AUTH_DATA, { authenticationEnabled: true, principal: data }));
      }).catch(err => {
        log(`error looking up path=${reqPath} status=${err}`);
        dispatch(makeAction(RECEIVE_AUTH_DATA, { authenticationEnabled: false }));
      });
  };
}

export const logout = () => {
  const { hostname, port, protocol } = window.location;
  getJson(`${protocol}//log:out@${hostname}:${port}/`)
    .then(() => {
      // nothing should happen here
    })
    .catch(() => {
      window.location = `${protocol}//${hostname}:${port}/`;
    });
};
