// @flow
// (Copyright) [2016 - 2016] Confluent, Inc.
import { makeAction } from 'actions/util';

import type { Action } from 'types';
import type { Connector } from './connectors';
import type { ConnectorPluginValidationResponse } from './connectorPlugins';
import type { FormStepKey } from 'types/form';

export const CONNECTOR_FORM_SEARCH_FAILED = 'CONNECTOR_FORM_SEARCH_FAILED';
export const CONNECTOR_FORM_SEARCH_REQUESTED = 'CONNECTOR_FORM_SEARCH_REQUESTED';
export const CONNECTOR_FORM_SEARCH_SUCCEEDED = 'CONNECTOR_FORM_SEARCH_SUCCEEDED';

export const CONNECTOR_FORM_FETCH_EDIT_FAILURE = 'CONNECTOR_FORM_FETCH_EDIT_FAILURE';
export type FetchEditFailureAction = Action<'CONNECTOR_FORM_FETCH_EDIT_FAILURE', { name: string, error: Object }>;
export const CONNECTOR_FORM_FETCH_EDIT_REQUEST = 'CONNECTOR_FORM_FETCH_EDIT_REQUEST';
export type FetchEditRequestAction = Action<'CONNECTOR_FORM_FETCH_EDIT_REQUEST', { name: string }>;
export const CONNECTOR_FORM_FETCH_EDIT_SUCCESS = 'CONNECTOR_FORM_FETCH_EDIT_SUCCESS';
export type FetchEditSuccessAction = Action<'CONNECTOR_FORM_FETCH_EDIT_SUCCESS', { name: string, validationData: ConnectorPluginValidationResponse, connector: Connector }>;
export const fetchEdit = {
  failure: (name: string, error: Error): FetchEditFailureAction => makeAction(CONNECTOR_FORM_FETCH_EDIT_FAILURE, { name, error }),
  request: (name: string, form: string): FetchEditRequestAction => makeAction(CONNECTOR_FORM_FETCH_EDIT_REQUEST, { name, form }),
  success: (name: string, validationData: ConnectorPluginValidationResponse, connector: Connector): FetchEditSuccessAction => makeAction(CONNECTOR_FORM_FETCH_EDIT_SUCCESS, { name, validationData, connector })
};

export const CONNECTOR_FORM_SUBMIT_FAILURE = 'CONNECTOR_FORM_SUBMIT_FAILURE';
export type SubmitFailureAction = Action<'CONNECTOR_FORM_SUBMIT_FAILURE', { name: string, reason: string }>;
export const CONNECTOR_FORM_SUBMIT_REQUEST = 'CONNECTOR_FORM_SUBMIT_REQUEST';
export type SubmitRequestAction = Action<'CONNECTOR_FORM_SUBMIT_REQUEST', { name: string }>;
export const CONNECTOR_FORM_SUBMIT_SUCCESS = 'CONNECTOR_FORM_SUBMIT_SUCCESS';
export type SubmitSuccessAction = Action<'CONNECTOR_FORM_SUBMIT_SUCCESS', { form: string, name: string }>;
export const submit = {
  failure: (name: string, reason: string): SubmitFailureAction => makeAction(CONNECTOR_FORM_SUBMIT_FAILURE, { name, reason }),
  request: (name: string, form: string): SubmitRequestAction => makeAction(CONNECTOR_FORM_SUBMIT_REQUEST, { name, form }),
  success: (name: string, form: string): SubmitSuccessAction => makeAction(CONNECTOR_FORM_SUBMIT_SUCCESS, { name, form })
};

export const CONNECTOR_FORM_VALIDATE_FAILURE = 'CONNECTOR_FORM_VALIDATE_FAILURE';
export type ValidateFailureAction = Action<'CONNECTOR_FORM_VALIDATE_FAILURE', { name: string, validationData: ConnectorPluginValidationResponse }>;
export const CONNECTOR_FORM_VALIDATE_REQUEST = 'CONNECTOR_FORM_VALIDATE_REQUEST';
export type ValidateRequestAction = Action<'CONNECTOR_FORM_VALIDATE_REQUEST', { name: string }>;
export const CONNECTOR_FORM_VALIDATE_SUCCESS = 'CONNECTOR_FORM_VALIDATE_SUCCESS';
export type ValidateSuccessAction = Action<'CONNECTOR_FORM_VALIDATE_SUCCESS', { name: string, validationData: ConnectorPluginValidationResponse }>;
export const validate = {
  failure: (name: string, validationData: ConnectorPluginValidationResponse): ValidateFailureAction => makeAction(CONNECTOR_FORM_VALIDATE_FAILURE, { name, validationData }),
  request: (name: string, form: string): ValidateRequestAction => makeAction(CONNECTOR_FORM_VALIDATE_REQUEST, { name, form }),
  success: (name: string, validationData: ConnectorPluginValidationResponse): ValidateSuccessAction => makeAction(CONNECTOR_FORM_VALIDATE_SUCCESS, { name, validationData })
};

export const LOAD_CONNECTOR_FOR_EDITING = 'LOAD_CONNECTOR_FOR_EDITING';
export type LoadConnectorForEditingAction = Action<'LOAD_CONNECTOR_FOR_EDITING', { name: string, form: string }>;
export const loadConnectorForEditing = (name: string, form: string): LoadConnectorForEditingAction => makeAction(LOAD_CONNECTOR_FOR_EDITING, { name, form });

export const STEP_SET_ACCESSIBLE = 'STEP_SET_ACCESSIBLE';
export type SetStepAccessibleAction = Action<'STEP_SET_ACCESSIBLE', { step: FormStepKey }>;
export const setStepAccessible = (step: FormStepKey): SetStepAccessibleAction => makeAction(STEP_SET_ACCESSIBLE, { step });

export const CONNECTOR_FORM_SHOW_ERRORS = 'CONNECTOR_FORM_SHOW_ERRORS';
export type ShowErrorsAction = Action<'CONNECTOR_FORM_SHOW_ERRORS', { step: FormStepKey }>;
export const showErrors = (step: FormStepKey): ShowErrorsAction => makeAction(CONNECTOR_FORM_SHOW_ERRORS, { step });

export const START_SUBMIT = 'START_SUBMIT';
export type SubmitFormAction = Action<'START_SUBMIT', { form: string }>;
export const submitForm = (form: string): SubmitFormAction => makeAction(START_SUBMIT, { form });
