// @flow
// (Copyright) [2016 - 2016] Confluent, Inc.
import { makeAction } from 'actions/util';

import type { Action } from 'types';
import type { ConnectorConfig } from './connectors';

export type ConnectorPluginValidationConfig = {
  definition: {
    default_value: string,
    dependents: Array<string>,
    display_name: string,
    documentation: string,
    group: string | null,
    importance: 'HIGH' | 'MEDIUM' | 'LOW',
    name: string,
    order: number,
    required: boolean,
    type: 'BOOLEAN' | 'CLASS' | 'DOUBLE' | 'INT' | 'LIST' | 'LONG' | 'PASSWORD' | 'SHORT' | 'STRING',
    width: 'FULL' | 'LONG' | 'MEDIUM' | 'SHORT'
  },
  value: {
    name: string,
    value: string,
    recommended_values: Array<string>,
    errors: Array<string>,
    visible: boolean
  }
};

export type ConnectorPluginValidationResponse = {
  configs: Array<ConnectorPluginValidationConfig>,
  error_count: number,
  groups: Array<string>,
  name: string
};

export const CONNECTOR_PLUGIN_VALIDATE_SUCCESS = 'CONNECTOR_PLUGIN_VALIDATE_SUCCESS';
export type ConnectorPluginValidateSuccessAction = Action<'CONNECTOR_PLUGIN_VALIDATE_SUCCESS', { name: string, validationData: ConnectorPluginValidationResponse }>;
export const CONNECTOR_PLUGIN_VALIDATE_REQUEST = 'CONNECTOR_PLUGIN_VALIDATE_REQUEST';
export type ConnectorPluginValidateRequestAction = Action<'CONNECTOR_PLUGIN_VALIDATE_REQUEST', { name: string, config: ConnectorConfig }>;
export const CONNECTOR_PLUGIN_VALIDATE_FAILURE = 'CONNECTOR_PLUGIN_VALIDATE_FAILURE';
export type ConnectorPluginValidateFailureAction = Action<'CONNECTOR_PLUGIN_VALIDATE_FAILURE', { name: string, error: Object }>;
export const validate = {
  failure: (name: string, error: Error): ConnectorPluginValidateFailureAction => makeAction(CONNECTOR_PLUGIN_VALIDATE_FAILURE, { name, error }),
  request: (name: string, config: ConnectorConfig): ConnectorPluginValidateRequestAction => makeAction(CONNECTOR_PLUGIN_VALIDATE_REQUEST, { name, config }),
  success: (name: string, validationData: ConnectorPluginValidationResponse): ConnectorPluginValidateSuccessAction => makeAction(CONNECTOR_PLUGIN_VALIDATE_SUCCESS, { name, validationData })
};

export const CONNECTOR_PLUGINS_VALIDATE_CONFIG = 'CONNECTOR_PLUGINS_VALIDATE_CONFIG';
export type ValidateConfigAction = Action<'CONNECTOR_PLUGINS_VALIDATE_CONFIG', { config: ConnectorConfig }>;
export const validateConfig = (config: ConnectorConfig): ValidateConfigAction => makeAction(CONNECTOR_PLUGINS_VALIDATE_CONFIG, { config });
