// @flow
// (Copyright) [2016 - 2016] Confluent, Inc.
import React from 'react';

import {
  FieldHelp,
  FormItem,
  LabeledSwitch,
  LabeledTextInput,
  Select
} from 'components/form';

import { InputTypes } from 'constants/management';

import type { FieldSectionField, ReduxFormPassedInput } from 'types/form';


export type FieldInputProps = {
  active: boolean,
  asyncValidating: boolean,
  dirty: boolean,
  error?: string,
  invalid: boolean,
  input: ReduxFormPassedInput & {
    errorsAreVisible: boolean,
    sectionField: FieldSectionField
  }
};

const FieldInput = (props: FieldInputProps) => {

  const { sectionField, errorsAreVisible, ...reduxFormInputProps } = props.input;

  const hasError = Boolean(props.error);
  const hasInfo = Boolean(sectionField.documentation || sectionField.defaultValue);

  const showErrorIndicator = hasError && (Boolean(reduxFormInputProps.value) || reduxFormInputProps.touched || errorsAreVisible);

  const hasInstantFeedbackError = sectionField.instantErrorFeedback && showErrorIndicator;
  const hasValidError = hasError && (hasInstantFeedbackError || reduxFormInputProps.touched || errorsAreVisible);

  const childProps = {
    active: props.active,
    reduxFormInputProps,
    showErrorIndicator,
    showInfoIcon: hasInfo,
    sectionField
  };

  return (
    <FormItem
      isActive={props.active}
      colSpan={sectionField.colSpan}
      hasMoreInfo={hasInfo}
      hasValidError={hasValidError}
      tipRenderer={(infoOnly: boolean) => (
        <FieldHelp
          defaultValue={sectionField.defaultValue}
          documentation={sectionField.documentation}
          error={infoOnly ? null : props.error}
        />
      )}
    >
      {(inputType => {
        switch (inputType) {
          case InputTypes.PASSWORD:
            return <LabeledTextInput {...childProps} type="password" />;
          case InputTypes.TEXT:
            return <LabeledTextInput {...childProps} type="text" />;
          case InputTypes.NUMBER:
            return <LabeledTextInput {...childProps} type="number" />;
          case InputTypes.SWITCH:
            return <LabeledSwitch {...childProps} />;
          case InputTypes.SELECT:
            return <Select {...childProps} />;
          case InputTypes.FREEFORM_SELECT:
            return <Select {...childProps} canCreate={true} />;
          default:
            return null;
        }
      })(sectionField.inputType)}
    </FormItem>
  );
};

export default FieldInput;


export const constructPlaceholderText = (sectionField: FieldSectionField) =>
  sectionField.placeholder == null
    ? null
    : `${sectionField.placeholder}${sectionField.required ? '*' : ''}`;
