// @flow
// (Copyright) [2016 - 2016] Confluent, Inc.
import React, { Component } from 'react';
import { connect } from 'react-redux';
import { FlexColumn } from 'react-virtualized';
import { ContentPanel } from 'components/layout';
import { FluidTable } from 'components/table';
import { alertsHistory } from 'actions/alerts';

import styles from './RestAPI.css';


const rowItems = [
  {
    name: 'limit',
    description: 'Integer representing the maximum number of records to return.',
    default: 'Default',
    value: '50'
  },
  {
    name: 'ts',
    description: 'Timestamp defining the most recent alert to return (in milliseconds since epoch).',
    default: 'Default',
    value: 'null'
  }
];

export class RestAPI extends Component {

  componentDidMount() {
    if (this.props.alerts.length === 0) {
      this.props.requestHistory({
        type: 'MAIN',
        itemId: null,
        count: 1
      });
    }
  }

  render() {
    const alerts = this.props.alerts.slice(0, 1);
    const displayText = JSON.stringify(alerts, null, 2).replace('\n]', '\n  ...\n]');
    const rowGetter = ({ index }) => rowItems[index];

    return (
      <ContentPanel>
        <div className={styles['content']}>
          <div className={styles['rest-action-title-line']}>
            <div className={styles['rest-action-button']}>GET</div>
            <div className={styles['rest-action-path']}><a href="/2.0/alerts/history">/2.0/alerts/history</a></div>
          </div>
          <div className={styles['heading-row']}>
            <div className={styles['heading-left']}>Response</div>
            <div className={styles['heading-right']} />
          </div>
          <div className={styles['response-box']}>
            <pre>{displayText}</pre>
          </div>
          <div className={styles['heading-row']}>
            <div className={styles['heading-left']}>Optional parameters</div>
          </div>
          <div className={styles['info-table']}>
            <FluidTable rowData={rowItems} headerHeight={0} >
              <FlexColumn rowHeader={true} dataKey="name" rowGetter={rowGetter} width={50} />
              <FlexColumn rowHeader={true} dataKey="description" rowGetter={rowGetter} width={50} flexGrow={1} />
              <FlexColumn rowHeader={true} dataKey="default" cellRenderer={({ rowIndex }) => <div className={styles['default-text']}>{rowItems[rowIndex].default}</div>} width={50} />
              <FlexColumn rowHeader={true} dataKey="value" rowGetter={rowGetter} width={50} />
            </FluidTable>
          </div>
        </div>
      </ContentPanel>
    );
  }
}

export default connect(
  state => ({
    alerts: state.alerts.history.main
  }),
  {
    requestHistory: alertsHistory.request
  }
)(RestAPI);
