// @flow
// (Copyright) [2016 - 2016] Confluent, Inc.
import React, { Component } from 'react';

import { CHART_PADDING_BOTTOM } from 'constants/monitoring/layout';

import { LineExtendDirections } from './hoverUtil';
import styles from './ChartHover.css';

import type {
  TimeSeries,
  MultiTimeSeries,
  LatencyData
} from 'types/monitoring/data';

import type {
  TimeScale,
  NumberScale
} from 'types/monitoring';

import type {
  HoverFormatter
} from './hoverUtil';

export class ChartHover extends Component {
  props: {
    lineSlotData?: ?TimeSeries,
    areaSlotData?: ?TimeSeries,
    multiSlotData?: ?MultiTimeSeries<LatencyData>,
    mouseOverTime: ?Date,
    xScale: TimeScale,
    yScale: NumberScale,
    hoverFormatter: HoverFormatter
  };

  render() {

    const {
      lineSlotData,
      areaSlotData,
      multiSlotData,
      mouseOverTime,
      xScale,
      yScale,
      hoverFormatter
    } = this.props;

    if (!hoverFormatter || !mouseOverTime || !(lineSlotData || areaSlotData || multiSlotData)) {
      return null;
    }

    const hoverInfo = hoverFormatter(lineSlotData, areaSlotData, multiSlotData, mouseOverTime, xScale, yScale);
    if (!hoverInfo) {
      return null;
    }

    const { ptX, ptY, label, lineExtendDirection, maxTextLength } = hoverInfo;

    const textClass = ptX > xScale.range()[1] - maxTextLength
      ? 'hover-text-ralign'
      : 'hover-text-lalign';

    return (
      <g className={styles['hover-root']}>
        {lineExtendDirection === LineExtendDirections.UP ||
         lineExtendDirection === LineExtendDirections.UPDOWN
            ? <line x1={ptX} x2={ptX} y1={ptY} y2="0" className={styles['hover-line-style']} />
            : null}
        {lineExtendDirection === LineExtendDirections.DOWN ||
         lineExtendDirection === LineExtendDirections.UPDOWN
            ? <line x1={ptX} x2={ptX} y1={ptY} y2={yScale.range()[0]+CHART_PADDING_BOTTOM} className={styles['hover-line-style']} />
            : null}
        <circle cx={ptX} cy={ptY} r="2" className={styles['hover-circle-style']} />
        <text x={ptX} y={ptY} className={styles[textClass]}>{label}</text>
      </g>
    );
  }
}

export default ChartHover;
