// @flow
// (Copyright) [2016 - 2016] Confluent, Inc.
import React from 'react';
import PureComponent from 'components/util/PureComponent';

import styles from './RangeChartInner.css';

import type {
  MultiTimeSeries,
  LatencyData
} from 'types/monitoring/data';

import type {
  TimeScale,
  NumberScale,
  TimeSpan
} from 'types/monitoring';

export class RangeChartInner extends PureComponent {
  props: {
    slotData: MultiTimeSeries<LatencyData>,
    slotWidthPx: number,
    xScale: TimeScale,
    yScale: NumberScale,
    missingRegions: Array<TimeSpan> // pre-condition is that these must be sorted.
  };

  render() {
    const { xScale, yScale, slotData, slotWidthPx, missingRegions } = this.props;

    if (!slotData || !slotData.values) {
      return null;
    }

    const { averageLatency, minLatency, maxLatency } = slotData.values;

    const elements = [];
    let missingRegionIdx = 0;
    for (let i=0; i<averageLatency.length; ++i) {
      const val = averageLatency[i];
      const timeMs = slotData.startTimeMs + i*slotData.stepMs;

      // if timeMs is within any missing region, make missingRegionIdx point to that region.
      while (
        missingRegionIdx < missingRegions.length-1 &&
        missingRegions[missingRegionIdx].endTime.getTime() <= timeMs
      ) {
        missingRegionIdx += 1;
      }

      const notMissing =
        missingRegions.length === 0 ||
        timeMs < missingRegions[missingRegionIdx].startTime.getTime() ||
        // endTime refers to the end of the bin so >= is what is needed here.
        timeMs >= missingRegions[missingRegionIdx].endTime.getTime();

      const rectStyle = notMissing
        ? styles['rect']
        : styles['rect-missing'];

      const midStyle = notMissing
        ? styles['mid-rect']
        : styles['mid-rect-missing'];

      if (val != null) {
        elements.push(
          <rect
            key={i}
            x={xScale(timeMs)+1}
            // $FlowFixMe - maxValues[i] will be null iff argValues is null.
            y={yScale(maxLatency[i])}
            width={slotWidthPx - 2}
            // $FlowFixMe - min/maxValues[i] will be null iff argValues is null.
            height={yScale(minLatency[i]) - yScale(maxLatency[i])}
            className={rectStyle}
          />
        );
        elements.push(
          <rect
            key={`${i}_`}
            x={xScale(timeMs)+1}
            y={yScale(val)}
            width={slotWidthPx - 2}
            height={2}
            className={midStyle}
          />
        );
      }
    }

    return <g>{elements}</g>;
  }
}

export default RangeChartInner;
