// @flow
// (Copyright) [2016 - 2016] Confluent, Inc.
import React, { Component } from 'react';
import { Link } from 'react-router';

import styles from './PopupMenuItem.less';
import { linkSpecToDisplaySpec } from './linkSpecUtil';

type PopupMenuItemProps = {
  linkSpec: Object,
  onClick?: Function
};

export class PopupMenuItem extends Component {
  props: PopupMenuItemProps;

  handleLinkClick() {
    if (this.props.onClick) {
      this.props.onClick();
    }
  }

  render() {
    const { linkSpec } = this.props;
    const displaySpec = linkSpecToDisplaySpec(linkSpec);

    if (!displaySpec) {
      return null;
    }

    const content = (
      <div className={displaySpec.path ? styles['link-root'] : styles['nolink-root']}>
        {displaySpec.parts.map((part, i) =>
          <div key={i} className={styles['part-root']}>
            <div className={styles['part-type']}>{part.type}</div>
            <div className={styles['part-name']}>{part.name}</div>
          </div>
        )}
      </div>
    );

    if (displaySpec) {
      return (
        <div className={styles['cell-root']}>
          {
            displaySpec.path
              ? <Link to={displaySpec.path} onClick={this.handleLinkClick.bind(this)}>{content}</Link>
              : content
          }
        </div>
      );
    }

    return null;
  }
}

export default PopupMenuItem;
