// @flow
// (Copyright) [2016 - 2016] Confluent, Inc.

export type DisplaySpec = {
  path: ?string,
  parts: Array<{type: string, name: string}>
};

export function linkSpecToDisplaySpec(linkSpec: ?Object): ?DisplaySpec {
  // TODO(norwood): combine all the route making here and in Monitoringbody.jsx

  if (!linkSpec) {
    return null;
  }

  if (linkSpec.topic && linkSpec.partition != null) {
    return {
      path: null,
      parts: [
        {
          type: 'TOPIC PARTITION',
          name: `${linkSpec.topic}: ${linkSpec.partition}`
        }
      ]
    };
  }

  if (linkSpec.topic) {
    return {
      path: null,
      parts: [
        {
          type: 'TOPIC',
          name: `${linkSpec.topic}`
        }
      ]
    };
  }

  if (linkSpec.clientId) {
    return {
      path: `/monitoring/consumers/${encodeURIComponent(linkSpec.clientId)}`,
      parts: [
        {
          type: 'CLIENT',
          name: linkSpec.clientId
        }
      ]
    };
  }

  if (linkSpec.group) {
    return {
      path: `/monitoring/consumer-groups/${encodeURIComponent(linkSpec.group)}`,
      parts: [
        {
          type: 'CONSUMER GROUP',
          name: linkSpec.group
        }
      ]
    };
  }

  return null;
}

export function estimateMenuItemWidth(linkSpec: Object, charWidthPx: number): number {
  const displaySpec = linkSpecToDisplaySpec(linkSpec);
  const forGoodLuck = 15;
  if (!displaySpec) {
    return forGoodLuck;
  }
  return displaySpec.parts.length * 8 +
    displaySpec.parts.reduce((p1, p2) => (p1 + p2.type.length*charWidthPx + p2.name.length*charWidthPx), 0) +
    forGoodLuck;
}

export function estimateMaxMenuItemWidth(linkSpecs: Array<Object>, charWidthPx: number, maxWidth: number): number {
  const maxLineWidth = Math.max(...(linkSpecs.map(ls => estimateMenuItemWidth(ls, charWidthPx))));
  return Math.min(maxWidth, maxLineWidth);
}

export function itemsHasFlaggedItem(/* items: Array<Object> */): boolean {
  // TODO(mhowlett): implement this when the server makes this data available.
  return false;
}
