// @flow
// (Copyright) [2016 - 2016] Confluent, Inc.
import React, { Component } from 'react';

import styles from './CheckboxGroup.css';
import { InlineLoader } from 'components/progress-indicator/InlineLoader';
import { Icon, IconNames } from 'components/icon';

export class CheckboxGroup extends Component {
  props: {
    isLoading: boolean,
    items: Array<{
      icon: $Enum<typeof IconNames>,
      label: any,
      value: any
    }>,
    onChange: (value: any) => any,
    showIcon: boolean,
    showLabel: boolean,
    selectedValue: any
  }
  static defaultProps = {
    isLoading: false,
    items: [],
    onChange: () => {},
    showIcon: true,
    showLabel: true
  };
  render() {
    const {
      isLoading,
      items,
      onChange,
      selectedValue,
      showIcon,
      showLabel
    } = this.props;

    return (
      <div className={styles[`root${isLoading ? '-loading' : ''}${!showLabel ? '-icons' : ''}`]}>
        {isLoading && (
          <div className={styles['loading-container']}>
            <InlineLoader />
          </div>
        )}
        {items.map(item => {
          const isSelected = selectedValue === item.value;
          return (
            <button
              className={isSelected ? styles.selected : styles['not-selected']}
              key={item.value}
              disabled={isSelected}
              onClick={() => {
                if (!isSelected) {
                  onChange(item.value);
                }
              }}
              title={item.label}
              type="button"
            >
              {showIcon && (
                <Icon
                  name={item.icon}
                  size={16}
                />
              )}

              {showLabel && (
                item.label
              )}
            </button>
          );
        })}
      </div>
    );
  }
}

export default CheckboxGroup;
