// @flow
// (Copyright) [2016 - 2016] Confluent, Inc.
import React, { Component } from 'react';
import { withRouter } from 'react-router';
import { change, reduxForm } from 'redux-form';
import { connect } from 'react-redux';

import { Form } from 'components/form';
import type { FormType, FieldValue } from 'types/form';

export class ConnectedForm extends Component {
  props: {
    fieldSections: Array<Object>,
    initialChangeValues: Array<FieldValue>,
    change: Function,
    formType: FormType
  }

  componentDidMount() {
    this.props.initialChangeValues.forEach(field => {
      this.props.change(this.props.formType, field.field, field.value);
    });
  }

  render() {
    return (
      <Form
        errorsAreVisible={true}
        fieldSections={this.props.fieldSections}
        showTitles={true}
      />
    );
  }
}


const withReduxForm = (ComposedComponent: ReactClass<ConnectedForm>) =>
  class extends Component {
    displayName: 'withReduxForm';

    props: {
      formType: FormType
    }

    component: ReactClass<ConnectedForm>;

    createComponent(props: any) {
      this.component = withRouter(reduxForm(
        {
          destroyOnUnmount: true,
          form: props.formType,
          propNamespace: 'reduxFormProps'
        }
      )(ComposedComponent));
    }

    constructor(props: any, context: any) {
      super(props, context);
      this.createComponent(props);
    }

    componentWillReceiveProps(newProps: any) {
      // it's necessary to re-wrap the component with reduxForm when the form type changes.
      if (newProps.formType !== this.props.formType) {
        this.createComponent(newProps);
      }
    }

    render() {
      return (
        <this.component key={this.props.formType} {...this.props} />
      );
    }
  };

export default withReduxForm(connect(
  (state, props) => (
    {
      fieldSections: props.fieldSectionsSelector(state)
    }
  ),
  { change }
)(ConnectedForm));
