// @flow
// (Copyright) [2016 - 2016] Confluent, Inc.
import React, { Component } from 'react';
import { throttle } from 'lodash';

import styles from './FormItem.css';
import { Popover } from 'components/tooltip';

export const basisMultiplier = 5.5;

export class FormItem extends Component {
  props: {
    basisMultiplier: number,
    children?: any,
    colSpan: number,
    hasMoreInfo: boolean,
    hasValidError: boolean,
    isActive: boolean,
    tipRenderer?: (infoOnly: boolean) => any
  };

  state: {
    isFirstItemInRow: boolean,
    isHovered: boolean
  };

  static defaultProps = {
    basisMultiplier: basisMultiplier,
    hasMoreInfo: false,
    hasValidError: false,
    isActive: false
  };

  rootEl: HTMLDivElement;

  checkIfFirstItemInRow: () => void = () => {
    if (this.rootEl !== null) {
      const isFirstItemInRow = this.rootEl.offsetLeft === 0;
      // only setState if necessary to prevent unnecessary componentDidUpdate
      if (this.state.isFirstItemInRow !== isFirstItemInRow) {
        this.setState({
          isFirstItemInRow
        });
      }
    }
  };

  constructor() {
    super();
    this.state = {
      isHovered: false,
      isFirstItemInRow: true
    };
    this.checkIfFirstItemInRow = throttle(this.checkIfFirstItemInRow.bind(this), 50);
  }

  componentDidMount() {
    this.checkIfFirstItemInRow();
    window.addEventListener('resize', this.checkIfFirstItemInRow);
  }

  componentDidUpdate() {
    this.checkIfFirstItemInRow();
  }

  componentWillUnmount() {
    window.removeEventListener('resize', this.checkIfFirstItemInRow);
    this.checkIfFirstItemInRow.cancel();
  }

  render() {
    const { state, props } = this;

    const showInfoTip = props.hasMoreInfo && state.isHovered;
    const showErrorTip = props.hasValidError && (state.isHovered || props.isActive);

    const openPopover = showErrorTip || showInfoTip;

    return (
      <div
        onMouseEnter={() => this.setState({ isHovered: true })}
        onMouseLeave={() => this.setState({ isHovered: false })}
        ref={el => this.rootEl = el}
        style={{ flexBasis: `${props.colSpan * props.basisMultiplier}rem` }}
        className={styles[`form-item-root${state.isFirstItemInRow ? '-first-in-row' : ''}`]}
      >
        <Popover
          body={openPopover && props.tipRenderer ? props.tipRenderer(!showErrorTip) : ''}
          isOpen={openPopover}
        >
          {props.children}
        </Popover>
      </div>
    );
  }
}

export default FormItem;
