// @flow
// (Copyright) [2016 - 2016] Confluent, Inc.
import React, { Component } from 'react';

import Label from './Label';
import Switch from './Switch';
import styles from './LabeledSwitch.css';
import { constructPlaceholderText } from 'components/FieldInput/FieldInput';

import type { FormField, FieldSectionField } from 'types/form';

export class LabeledSwitch extends Component {
  props: {
    active: boolean,
    reduxFormInputProps: FormField,
    sectionField: FieldSectionField,
    showErrorIndicator: boolean,
    showInfoIcon: boolean
  };

  static defaultProps = {
    showErrorIndicator: false,
    showInfoIcon: false
  };

  render() {
    const {
      active,
      reduxFormInputProps,
      sectionField,
      showErrorIndicator,
      showInfoIcon
    } = this.props;

    const switchInnerSelector = `labeled-switch-inner-root${
      showErrorIndicator ? '--error' : (
        active ? '--active' : ''
      )
    }`;

    return (
      <Label
        disabled={reduxFormInputProps.disabled}
        id={sectionField.id}
        staticPlaceholder={true}
        text={constructPlaceholderText(sectionField)}
        showInfoIcon={showInfoIcon}
      >
        <div className={styles[switchInnerSelector]}>
          <Switch
            {...reduxFormInputProps}
            id={sectionField.id}
            onText={sectionField.onText} // eslint-disable-line react/jsx-handler-names
            offText={sectionField.offText}
          />
        </div>
      </Label>
    );
  }
}

export default LabeledSwitch;
