// @flow
// (Copyright) [2016 - 2016] Confluent, Inc.
import React, { Component } from 'react';

import type { FormField } from 'types/form';
import styles from './Switch.css';

export class Switch extends Component {
  props: FormField & {
    'aria-label'?: string,
    'aria-labelledby'?: string,
    disabled: boolean,
    id?: string,
    offText: string,
    onText: string
  };

  static defaultProps = {
    disabled: false,
    offText: 'off',
    onText: 'on'
  };

  checkbox: HTMLInputElement;

  handleClick: (e: SyntheticMouseEvent) => void = (e) => {
    const { checkbox } = this;

    if (e.target !== checkbox) {
      e.preventDefault();
      checkbox.focus();
      checkbox.click();
      return;
    }
  };

  render() {
    const { offText, onText, ...inputProps } = this.props;
    const { value, disabled } = this.props;

    return (
      <div className={styles['switch-root']}>
        <div className={styles['text']}>
          {value ? onText : offText}
        </div>
        <div
          className={styles[`switch-container${disabled ? '--disabled' : ''}`]}
          onClick={disabled ? this.handleClick : null}
        >
          <div className={styles[`slider-container${value ? '--checked' : ''}`]} />
          <input
            {...inputProps}
            checked={'checked' in inputProps ? inputProps.checked : value}
            ref={(el: HTMLInputElement) => this.checkbox = el}
            className={styles['checkbox']}
            type="checkbox"
          />
          <div className={styles[`bauble${value ? '--checked' : ''}`]} />
        </div>
      </div>
    );
  }
}

export default Switch;
