// @flow
// (Copyright) [2016 - 2016] Confluent, Inc.
import React, { Component } from 'react';
import { SizeEmittingContentPanel } from 'components/layout';
import { BigDataTableWithNotifications } from 'components/table';

import styles from './TableContentPanel.css';

export const ROW_HEIGHT_PX = 40;
export const HEADER_HEIGHT_PX = 35;

export function calculateTableHeight(availableHeight: number, numberOfRows: number) {
  const padding = 10;
  const fullTableHeight = numberOfRows * ROW_HEIGHT_PX + HEADER_HEIGHT_PX + padding;
  return fullTableHeight < availableHeight ? fullTableHeight : availableHeight;
}


export class TableContentPanel extends Component {
  props: {
    rowData: Array<Object>,
    notificationText?: ?string,
    children?: any,
    onNotificationClick?: Function,
    onHitBottom?: Function
  }

  render() {
    return (
      <SizeEmittingContentPanel>
        {(availableHeight) => {
          return (
            <div className={styles.root}>
              <BigDataTableWithNotifications
                rowData={this.props.rowData}
                height={calculateTableHeight(availableHeight, this.props.rowData.length)}
                rowHeight={ROW_HEIGHT_PX}
                headerHeight={HEADER_HEIGHT_PX}
                notificationText={this.props.notificationText}
                onNotificationClick={this.props.onNotificationClick}
                onHitBottom={this.props.onHitBottom}
              >
                {this.props.children}
              </BigDataTableWithNotifications>
            </div>
          );
        }}
      </SizeEmittingContentPanel>
    );
  }
}

export default TableContentPanel;
