// @flow
// (Copyright) [2016 - 2016] Confluent, Inc.
import React, { Component } from 'react';
import { connect } from 'react-redux';
import moment from 'moment';

import { loadLicenseData } from 'actions/license';
import { LICENSE_SUBSCRIPTION_URL } from 'constants/license'; // TODO(norwood): this is for expired subs, but we show it even if we aren't expired

import styles from './LicenseCountdown.css';

export const LABEL_MISSING = 'Unable to check license';
export const LABEL_FUTURE = 'License expires';
export const LABEL_PAST = 'License expired';

export class LicenseCountdown extends Component {
  props: {
    label: string,
    value: string,
    loadLicenseData: () => void
  };

  static defaultProps = {
    loadLicenseData: () => {}
  };

  componentWillMount() {
    this.props.loadLicenseData();
  }

  render() {
    return (
      <a
        href={LICENSE_SUBSCRIPTION_URL}
        target="_blank"
        rel="noopener noreferrer"
        className={styles['license-info-root']}
      >
        <span className={styles['license-label']}>{this.props.label}</span>
        <span className={styles['license-value']}>{this.props.value}</span>
      </a>
    );
  }
}

export function select(state: any): { label: string, value: string | null } {
  const expiration = state && state.license && state.license.expiration != null
    ? moment(state.license.expiration)
    : null;
  let label = LABEL_FUTURE;
  let value = null;
  if (expiration == null) {
    label = LABEL_MISSING;
  } else if (expiration.isBefore(moment())) {
    label = LABEL_PAST;
    value = `${expiration.toNow(true)} ago`;
  } else {
    value = `in ${expiration.fromNow(true)}`;
  }
  return {
    label,
    value
  };
}

export default connect(select, { loadLicenseData })(LicenseCountdown);
