// @flow
// (Copyright) [2016 - 2016] Confluent, Inc.
import React, { Component } from 'react';
import { browserHistory } from 'react-router';
import { connect } from 'react-redux';

import { ConnectorStatusActions } from '.';
import { CheckboxGroup } from 'components/form';
import { deleteConnector, loadConnectorStatus } from 'actions/connectors';

export class ConnectorActionBar extends Component {
  props: {
    loadConnectorStatus: (connectorName: string) => any,
    deleteConnector: (connectorName: string) => any,
    params: {
      connectorName: string
    },
    route: {
      routedFormData: {
        redirectPathname?: string
      }
    }
  };

  componentWillMount() {
    this.props.loadConnectorStatus(this.props.params.connectorName);
  }

  render() {
    const {
      deleteConnector,
      params: { connectorName: name },
      route: { routedFormData: { redirectPathname } }
    } = this.props;

    return (
      <ConnectorStatusActions name={name}>
        {(status, isTransitioning, pause, resume, options) => {
          if (status === 'DELETED' && typeof redirectPathname !== 'undefined') {
            browserHistory.push(redirectPathname);
          }
          return (
            <div>
              <CheckboxGroup
                items={[
                  ...options
                ]}
                showLabel={false}
                onChange={selectedVal => {
                  switch (selectedVal) {
                    case 'PAUSED':
                      pause();
                      break;
                    case 'RUNNING':
                      resume();
                      break;
                  }
                }}
                selectedValue={status}
                isLoading={isTransitioning}
              />
              <CheckboxGroup
                items={[
                  {
                    icon: 'trashSm',
                    label: 'Delete',
                    value: 'DELETE'
                  }
                ]}
                onChange={selectedVal => {
                  switch (selectedVal) {
                    case 'DELETE':
                      deleteConnector(name);
                      break;
                  }
                }}
                isLoading={status === 'DELETING' || status === 'DELETED'}
                selectedValue={null}
                showLabel={false}
              />
            </div>
          );
        }}
      </ConnectorStatusActions>
    );
  }
}

export default connect(undefined, {
  deleteConnector,
  loadConnectorStatus
})(ConnectorActionBar);
