// @flow
// (Copyright) [2016 - 2016] Confluent, Inc.
import React, { Component } from 'react';

import { MonitoringDataTypes } from 'types/monitoring';
import type { MonitoringDataType } from 'types/monitoring';

import { Axis } from 'components/charting';
import AreaLineChart from 'components/charting/charts/area-line-chart';
import RangeChart from 'components/charting/charts/range-chart';
import { RangeTypes } from 'constants/monitoring/timeframe';

import d3scale from 'd3-scale';

import {
  parseData,
  transformMissingData
} from 'selectors/monitoring/data';
import {
  calcSlotWidthPx,
  calcSlotWidthMs
} from 'selectors/monitoring';

import type { HoverFormatter } from 'components/charting/charts/hoverUtil';

import styles from './MonitoringChart.css';

const Y_AXIS_WIDTH_PX = 0;


export class MonitoringChart extends Component {
  props: {
    width: number,
    height: number,
    type: MonitoringDataType,
    data: Object,
    startTimeSlotQuantizedMs: number,
    stopTimeSlotQuantizedMs: number,
    mouseOverTime: ?Date,
    hoverFormatter: ?HoverFormatter
  }

  render() {
    const { data, startTimeSlotQuantizedMs, stopTimeSlotQuantizedMs, width, height } = this.props;

    const xScale = d3scale.scaleTime().domain([startTimeSlotQuantizedMs, stopTimeSlotQuantizedMs]).range([0, width]);

    let monitoringData = {};
    let slotWidth = null;
    if (data) {
      monitoringData = parseData(
        data,
        data.startTimeMs,
        data.stepMs,
        startTimeSlotQuantizedMs,
        stopTimeSlotQuantizedMs
      );
      transformMissingData(monitoringData);

      const slotWidthMs = calcSlotWidthMs(width, 15000, startTimeSlotQuantizedMs, stopTimeSlotQuantizedMs);
      slotWidth = {
        ms: slotWidthMs,
        px: calcSlotWidthPx(Y_AXIS_WIDTH_PX, width, slotWidthMs, startTimeSlotQuantizedMs, stopTimeSlotQuantizedMs)
      };
    }

    return (
      <div>
        <div className={styles['chart']}>
          {monitoringData != null && slotWidth != null && this.props.type === MonitoringDataTypes.DELIVERY
            ? <AreaLineChart
                height={height}
                xScale={xScale}
                slotWidth={slotWidth}
                lineData={monitoringData.produced.count}
                areaData={monitoringData.consumed.count}
                legend={null}
                mouseOverTime={this.props.mouseOverTime}
                hoverFormatter={this.props.hoverFormatter}
                timeframeRangeType={RangeTypes.FIXED}
                leftOverlayItems={null}
                rightOverlayItems={null}
                solidLeadingGuide={true}
                missingRegions={monitoringData.missing}
                disabled={false}
              />
            : null}
          {monitoringData != null && slotWidth != null && this.props.type === MonitoringDataTypes.LATENCY
            ? <RangeChart
                height={height}
                xScale={xScale}
                slotWidth={slotWidth}
                data={monitoringData.consumed.latency}
                legend={null}
                mouseOverTime={this.props.mouseOverTime}
                hoverFormatter={this.props.hoverFormatter}
                missingRegions={monitoringData.missing}
                disabled={false}
              />
            : null}
        </div>
        <Axis
          xScale={xScale}
          mouseOverTime={null}
          missingRegions={monitoringData.missing}
          styleClassName={'axis-styling-lighter'}
        />
      </div>
    );
  }
}

export default MonitoringChart;
