// @flow
// (Copyright) [2016 - 2016] Confluent, Inc.
import React, { Component } from 'react';
import { connect } from 'react-redux';
import { IndexLink } from 'react-router';

import * as authActions from 'actions/auth';
import logoSrc from 'static/logo.png';
import styles from './MainNavigation.css';
import { Account } from 'components/account';
import { LicenseCountdown } from 'components/license-countdown';
import { NavGroup } from 'components/navigation/NavGroup';
import { NavGroupItem } from 'components/navigation/NavGroupItem';

export class MainNavigation extends Component {
  props: {
    authenticationEnabled: boolean,
    loadAuthData: Function
  };

  componentWillMount() {
    const { loadAuthData } = this.props;
    loadAuthData && loadAuthData();
  }

  render() {
    const { authenticationEnabled } = this.props;
    return (
      <nav className={styles['root']}>
        <IndexLink to="/">
          <img
            alt="Confluent Logo"
            src={logoSrc}
            className={styles.logo}
            title="Confluent - Realtime Streams Powered by Apache Kafka"
          />
        </IndexLink>

        <div className={styles['nav-list-container']}>
          <NavGroup
            heading="Monitoring"
            prefix="/monitoring"
          >
            <NavGroupItem
                pathname="/monitoring"
                icon="streams"
            >
              Data streams
            </NavGroupItem>
          </NavGroup>

          <NavGroup
            heading="Management"
            prefix="/management"
          >
            <NavGroupItem
              pathname="/management/connect"
              icon="connect"
            >
              Kafka Connect
            </NavGroupItem>
            <NavGroupItem
              pathname="/management/clusters"
              icon="clusters"
            >
              Clusters
            </NavGroupItem>
          </NavGroup>

          <NavGroup
            heading="Alerts"
            prefix="/alerts"
          >
            <NavGroupItem
              pathname="/alerts/overview"
              icon="overview"
            >
              Overview
            </NavGroupItem>
            <NavGroupItem
              pathname="/alerts/integration"
              icon="integration"
              useIndexLink={true}
            >
              Integration
            </NavGroupItem>
          </NavGroup>

        </div>
        <div className={styles.bottom}>
          {authenticationEnabled && (
            <div className={styles.accountContainer}>
              <Account />
            </div>
          )}
          <LicenseCountdown />
        </div>
      </nav>
    );
  }
}

const mapStateToProps = state => ({
  authenticationEnabled: state.auth.authenticationEnabled
});

export default connect(
  mapStateToProps,
  authActions
)(MainNavigation);
