// @flow
// (Copyright) [2016 - 2016] Confluent, Inc.
import React, { Component } from 'react';
import { Link } from 'react-router';

import type { LocationDescriptorObject } from 'types/navigation';

import styles from './SubNavigation.css';

export type LabeledPath = {
  label: string,
  location: LocationDescriptorObject
};
export type Links = Array<LabeledPath>;

export type SubNavigationProps = {
  isBelowContent: boolean,
  links: Links,
  padded: boolean,
  disabled: boolean
};

export class SubNavigation extends Component {

  props: SubNavigationProps;

  static defaultProps = {
    isBelowContent: false,
    padded: false,
    disabled: false
  };

  render() {
    const {
      isBelowContent,
      links,
      padded,
      disabled
    } = this.props;

    return (
      <div className={styles.root}>
        <nav className={styles[`nav-root${padded ? '-padded' : ''}`]}>
          {links.map((data, i) => (
            <Link
              {...(data.props || {})}
              activeClassName={
                styles[`nav-link-selected-${isBelowContent ? 'below' : 'above'}`]
              }
              key={i}
              className={styles[`nav-link-${isBelowContent ? 'below' : 'above'}`]}
              to={data.location}
            >
              {data.label}
            </Link>
          ))}
        </nav>
        {disabled && <div className={styles.unfocused} />}
      </div>
    );
  }
}

export default SubNavigation;
