// @flow
// (Copyright) [2016 - 2016] Confluent, Inc.
import React, { Component } from 'react';
import moment from 'moment';
import InlineSVG from 'svg-inline-react';

import { Button } from 'components/button';

import clockIcon from 'static/icons/sm/clock.svg';
import calendarIcon from 'static/icons/sm/calendar.svg';
import arrow from 'static/icons/sm/arrow.svg';

import styles from './MainControls.css';

import { PickerTargets, DateTimeFormats } from 'constants/timePicker';
import type { PickerTarget } from 'constants/timePicker';
import type { ButtonClassType } from 'components/button';

export type MainControlsProps = {
  startDayButtonType: ButtonClassType,
  startTimeButtonType: ButtonClassType,
  endDayButtonType: ButtonClassType,
  endTimeButtonType: ButtonClassType,
  startTime: number,
  endTime: number,
  onHandleMenuButtonClick: (pickerTarget: PickerTarget) => any
};

class MainControls extends Component {
  props: MainControlsProps;
  render() {
    const {
      startDayButtonType,
      startTimeButtonType,
      endDayButtonType,
      endTimeButtonType,
      startTime,
      endTime,
      onHandleMenuButtonClick
    } = this.props;
    return (
      <div className={styles['main-controls-root']}>
        <div className={styles['inner']}>
          <Button
            classType={startDayButtonType}
            text={moment.unix(startTime).format(DateTimeFormats.DATE)}
            icon={calendarIcon}
            onClick={() => onHandleMenuButtonClick(PickerTargets.START_DAY)}
          />
          <Button
            classType={startTimeButtonType}
            text={moment.unix(startTime).format(DateTimeFormats.TIME)}
            icon={clockIcon}
            onClick={() => onHandleMenuButtonClick(PickerTargets.START_TIME)}
          />
          <InlineSVG className={styles['arrow']} src={arrow} />
          <Button
            classType={endDayButtonType}
            text={moment.unix(endTime).format(DateTimeFormats.DATE)}
            icon={calendarIcon}
            onClick={() => onHandleMenuButtonClick(PickerTargets.END_DAY)}
          />
          <Button
            classType={endTimeButtonType}
            text={moment.unix(endTime).format(DateTimeFormats.TIME)}
            icon={clockIcon}
            onClick={() => onHandleMenuButtonClick(PickerTargets.END_TIME)}
          />
          <span className={styles['timezone']}>UTC {moment().utcOffset()/60}</span>
        </div>
      </div>
    );
  }
}

export default MainControls;
