// @flow
// (Copyright) [2016 - 2016] Confluent, Inc.
import { makeAction } from 'actions/util';

import type { Action } from 'types';

export type SelectableItem = {
  itemId: string,
  listName: string
};

export const SelectionStatuses = {
  ALL: 'ALL',
  NONE: 'NONE',
  SOME: 'SOME'
};

export type SelectionStatus = $Enum<typeof SelectionStatuses>;

export const SELECTION_LIST_SELECT_ITEM = 'SELECTION_LIST_SELECT_ITEM';
export type SelectItemAction = Action<'SELECTION_LIST_SELECT_ITEM', SelectableItem>;
export const selectItem = (listName: string, itemId: string): SelectItemAction => makeAction(SELECTION_LIST_SELECT_ITEM, { listName, itemId });

export const SELECTION_LIST_DESELECT_ITEM = 'SELECTION_LIST_DESELECT_ITEM';
export type DeselectItemAction = Action<'SELECTION_LIST_DESELECT_ITEM', SelectableItem>;
export const deselectItem = (listName: string, itemId: string): DeselectItemAction => makeAction(SELECTION_LIST_DESELECT_ITEM, { listName, itemId });

export const SELECTION_LIST_START_RANGE_SELECT = 'SELECTION_LIST_START_RANGE_SELECT';
export type StartRangeSelectAction = Action<'SELECTION_LIST_START_RANGE_SELECT', { listName: string, startIndex: number }>;
export const startRangeSelect = (listName: string, startIndex: number): StartRangeSelectAction => makeAction(SELECTION_LIST_START_RANGE_SELECT, { listName, startIndex });

export const SELECTION_LIST_END_RANGE_SELECT = 'SELECTION_LIST_END_RANGE_SELECT';
export type EndRangeSelectAction = Action<'SELECTION_LIST_END_RANGE_SELECT', { list: Array<any>, listName: string, endIndex: number, dataKey: string }>;
export const endRangeSelect = (listName: string, endIndex: number, list: Array<any>, dataKey: string): EndRangeSelectAction => makeAction(SELECTION_LIST_END_RANGE_SELECT, { list, listName, endIndex, dataKey });

export const SELECTION_LIST_SELECT_ALL = 'SELECTION_LIST_SELECT_ALL';
export type SelectAllAction = Action<'SELECTION_LIST_SELECT_ALL', { list: Array<any>, listName: string, dataKey: string }>;
export const selectAll = (listName: string, list: Array<any>, dataKey: string): SelectAllAction => makeAction(SELECTION_LIST_SELECT_ALL, { list, listName, dataKey });

export const SELECTION_LIST_DESELECT_ALL = 'SELECTION_LIST_DESELECT_ALL';
export type DeselectAllAction = Action<'SELECTION_LIST_DESELECT_ALL', { listName: string }>;
export const deselectAll = (listName: string): DeselectAllAction => makeAction(SELECTION_LIST_DESELECT_ALL, { listName });

export const SELECTION_LIST_INITIALIZE = 'SELECTION_LIST_INITIALIZE';
export type InitializeAction = Action<'SELECTION_LIST_INITIALIZE', { listName: string }>;
export const initialize = (listName: string): InitializeAction => makeAction(SELECTION_LIST_INITIALIZE, { listName });
