// @flow
// (Copyright) [2016 - 2016] Confluent, Inc.
import { browserHistory } from 'react-router';

import { formValueSelector } from 'redux-form';
import { InputTypes } from 'constants/management';
import { FormTypes } from 'types/form';

import { CLUSTERS_INDEX_PATHNAME } from './index';

import {
  loadClusterEditForm,
  saveClusterEditForm
} from 'actions/clusters';

import type { Dispatcher } from 'types';

const generalFieldSection = {
  title: 'General',
  fields: [
    {
      colSpan: 12,
      id: 'displayName',
      inputType: InputTypes.TEXT,
      instantErrorFeedback: false,
      placeholder: 'Cluster name',
      required: true
    }
  ]
};

export function fieldSectionsSelector() {
  return [
    generalFieldSection,
    {
      title: 'Zookeeper',
      fields: [
        {
          colSpan: 12,
          id: 'zookeeperConnect',
          inputType: InputTypes.SELECT,
          instantErrorFeedback: false,
          locked: true,
          multi: true,
          placeholder: 'Connections'
        }
      ]
    },
    {
      title: 'Bootstrap servers',
      fields: [
        {
          colSpan: 12,
          id: 'bootstrapServers',
          inputType: InputTypes.SELECT,
          instantErrorFeedback: false,
          locked: true,
          multi: true,
          placeholder: 'Hosts'
        }
      ]
    }
  ];
}

const clusterValueSelector = formValueSelector(FormTypes.CLUSTER_FORM);

function canSaveSelector(state: Object) {
  const getField = (fieldName) => clusterValueSelector(state, fieldName);

  const displayName = getField('displayName');

  if (typeof displayName !== 'string' || displayName.length === 0) {
    return false;
  }

  // TODO(@dylanharrington): check name for uniqueness?

  return true;
}


export const EditClusterFormSpec = {

  formType: FormTypes.CLUSTER_FORM,

  fieldSectionsSelector: () => {
    return fieldSectionsSelector();
  },

  actionBarButtonsSelector: (state: Object) => {
    return [
      {
        text: 'Cancel',
        isPrimary: false,
        isDisabled: false,
        onClick: () => {
          browserHistory.push(CLUSTERS_INDEX_PATHNAME);
        }
      },
      {
        text: 'Save cluster',
        isPrimary: true,
        isDisabled: !canSaveSelector(state),
        onClick: EditClusterFormSpec.formSubmitHandler
      }
    ];
  },

  modalComponent: null,

  initialChangeValues: [],

  formMountedHandler: (props: Object) => {
    const { clusterId } = props.params;
    props.dispatch(loadClusterEditForm(clusterId));
  },

  formSubmitHandler: (dispatch: Dispatcher) => {
    dispatch(saveClusterEditForm());
  },

  canSaveSelector: canSaveSelector
};
