// @flow
// (Copyright) [2016 - 2016] Confluent, Inc.
import type { Action } from 'types';

import {
  SET_FOCUSED_COMPONENT,
  SET_POPOVER_POSITION,
  UNSET_FOCUSED_COMPONENT,
  SET_VISIBLE_MODAL
} from 'actions/layout';

import type {
  ComponentType,
  SetFocusedComponentAction,
  SetPopoverPositionAction,
  SetVisibleModalAction
} from 'actions/layout';

export type FocusedSpec = {
  type: ComponentType,
  id: Object
};

export type LayoutState = {
  focusedComponent: ?FocusedSpec,
  popoverPosition: { pageX: number, pageY: number },
  visibleModalId: string | null
};

export const defaultState: LayoutState = {
  focusedComponent: null,
  popoverPosition: { pageX: 0, pageY: 0 },
  visibleModalId: null
};

function setFocusedComponent(state: LayoutState, action: SetFocusedComponentAction) {
  return {
    ...state,
    focusedComponent: action.payload
  };
}

function unsetFocusedComponent(state: LayoutState) {
  return {
    ...state,
    focusedComponent: null
  };
}

function setPopoverPosition(state: LayoutState, action: SetPopoverPositionAction): LayoutState {
  return {
    ...state,
    popoverPosition: action.payload
  };
}

function setVisibleModal(state: LayoutState, action: SetVisibleModalAction): LayoutState {
  return {
    ...state,
    visibleModalId: action.payload.id
  };
}


export default function layout(state: LayoutState = defaultState, action: Action<*, *>): LayoutState {
  switch (action.type) {
    case SET_FOCUSED_COMPONENT:
      return setFocusedComponent(state, action);
    case UNSET_FOCUSED_COMPONENT:
      return unsetFocusedComponent(state);
    case SET_POPOVER_POSITION:
      return setPopoverPosition(state, action);
    case SET_VISIBLE_MODAL:
      return setVisibleModal(state, action);
    default:
      return state;
  }
}
