// @flow
// (Copyright) [2016 - 2016] Confluent, Inc.

import debug from 'debug';

import {
  INCREMENT_CONNECTION_COUNT,
  DECREMENT_CONNECTION_COUNT,
  ALLOW_DATA_FETCH,
  DISALLOW_DATA_FETCH
} from 'actions/monitoring/dataManager';

import type { Action } from 'types';

const log = debug('controlcenter:actions:monitoring:dataManager');


export type DataManagerState = {
  connectionCount: number,
  preventFetch: boolean
};

export const defaultState: DataManagerState = {
  connectionCount: 0,
  preventFetch: false
};

export function incrementConnectionCount(state: DataManagerState): DataManagerState {
  return {
    ...state,
    connectionCount: state.connectionCount + 1
  };
}

export function decrementConnectionCount(state: DataManagerState): DataManagerState {
  if (state.connectionCount <= 0) {
    log('attempting to decrement connectionCount below 0.');
    return {
      ...state,
      connectionCount: 0
    };
  }
  return {
    ...state,
    connectionCount: state.connectionCount - 1
  };
}

export function allowDataFetch(state: DataManagerState): DataManagerState {
  return {
    ...state,
    preventFetch: false
  };
}

export function disallowDataFetch(state: DataManagerState): DataManagerState {
  return {
    ...state,
    preventFetch: true
  };
}

export function dataManager(state: DataManagerState = defaultState, action: Action<*, *>): ?Object {
  switch (action.type) {
    case INCREMENT_CONNECTION_COUNT:
      return incrementConnectionCount(state);
    case DECREMENT_CONNECTION_COUNT:
      return decrementConnectionCount(state);
    case ALLOW_DATA_FETCH:
      return allowDataFetch(state);
    case DISALLOW_DATA_FETCH:
      return disallowDataFetch(state);
    default:
      return state;
  }
}
