// @flow
// (Copyright) [2016 - 2016] Confluent, Inc.
import type { Action } from 'types';

import {
  UPDATE_END_TIME,
  UPDATE_FETCH_EXTENDED_END_TIME,
  SET_TIME_RANGE
} from 'actions/monitoring/timeframe';

import type { UpdateFetchExtendedEndTimeAction } from 'actions/monitoring/timeframe';
import type { RangeType } from 'constants/monitoring/timeframe';
import { RangeTypes } from 'constants/monitoring/timeframe';


export type TimeframeState = {
  startTimeMs: number,
  stopTimeMs: number,
  fetchExtendedStopTimeMs: number | null,
  rangeType: RangeType
};

export const defaultState: TimeframeState = {
  startTimeMs: Date.now() - (240*60*1000),
  stopTimeMs: Date.now(),
  fetchExtendedStopTimeMs: null,
  rangeType: RangeTypes.ROLLING
};

function updateEndTime(state: TimeframeState, action: Action<*, *>): any {
  switch (state.rangeType) {
    case RangeTypes.ROLLING:
      const rangeMs = state.stopTimeMs - state.startTimeMs;
      const startTimeMs = action.payload.endTimeMs - rangeMs;
      return {
        ...state,
        startTimeMs: startTimeMs,
        stopTimeMs: action.payload.endTimeMs,
        fetchExtendedStopTimeMs: null
      };

    case RangeTypes.GROWING_DAY:
    case RangeTypes.GROWING_WEEK:
    case RangeTypes.GROWING_MONTH:
      // note: when endTime ticks over to a new day / week / month the growing time
      // range will no longer equal day / week / month so far. An alternate behavior
      // would be for start date to jump at these boundaries, however this would be
      // more complicated to implement and I think less desirable.
      return {
        ...state,
        stopTimeMs: action.payload.endTimeMs,
        fetchExtendedStopTimeMs: null
      };

    case RangeTypes.FIXED:
      return {
        ...state,
        fetchExtendedStopTimeMs: null
      };

    default:
      return state;
  }
}

function updateFetchExtendedEndTime(state: TimeframeState, action: UpdateFetchExtendedEndTimeAction): any {
  return {
    ...state,
    fetchExtendedStopTimeMs: action.payload.endTimeMs
  };
}

function setTimeRange(state: TimeframeState, action: Action<*, *>): TimeframeState {
  if (action.payload) {
    return {
      startTimeMs: action.payload.startTimeMs,
      stopTimeMs: action.payload.stopTimeMs,
      fetchExtendedStopTimeMs: null,
      rangeType: action.payload.rangeType
    };
  }
  return state;
}

export function timeframe(state: TimeframeState = defaultState, action: Action<*, *>): any {
  switch (action.type) {
    case UPDATE_END_TIME:
      return updateEndTime(state, action);
    case UPDATE_FETCH_EXTENDED_END_TIME:
      return updateFetchExtendedEndTime(state, action);
    case SET_TIME_RANGE:
      return setTimeRange(state, action);
    default:
      return state;
  }
}
