// @flow
// (Copyright) [2016 - 2016] Confluent, Inc.

import debug from 'debug';

import { call, put, fork } from 'redux-saga/effects';
import { takeEvery } from 'redux-saga';
import {
  ALERTS_REQUEST_HISTORY,
  ALERTS_REQUEST_MONITORING_DATA,
  alertsHistory,
  alertsMonitoringData
} from 'actions/alerts';

import type {
  AlertsRequestHistoryAction,
  AlertsRequestMonitoringDataAction
} from 'actions/alerts';

import { Rollups } from 'types/monitoring';

import {
  RequestTypes,
  DataLayoutTypes
} from 'types/monitoring/data';

import { constructMonitoringDataRequest } from 'actions/monitoring/data';

import { getJson, encodeQueryData } from 'actions/util';


const log = debug('controlcenter:sagas:alerts:history');


export function* fetchHistorySaga(action: AlertsRequestHistoryAction): Generator<*, *, *> {
  const queryParams = encodeQueryData({
    ts: action.payload.itemId ? action.payload.itemId.timestamp : null,
    guid: action.payload.itemId ? action.payload.itemId.guid : null,
    limit: action.payload.count
  }, true);
  const req = `/2.0/alerts/history?${queryParams}`;

  try {
    const data = yield call(getJson, req);
    if (data != null) {
      yield put(alertsHistory.receive(action.payload, data));
    }
  } catch (error) {
    log(`error looking up path=${req} status=${error.message}`);
  }
}

export function* fetchMonitoringData(action: AlertsRequestMonitoringDataAction): Generator<*, *, *> {
  const params = {
    startTimeMs: action.payload.startTimeMs,
    stopTimeMs: action.payload.stopTimeMs,
    rollup: Rollups.FIFTEEN_SECONDS,
    type: RequestTypes.OVERVIEW,
    group: action.payload.consumerGroup
  };

  const req = constructMonitoringDataRequest(action.payload.clusterId, DataLayoutTypes.CONSUMER_GROUP, params);

  try {
    const data = yield call(getJson, req);
    if (data != null) {
      yield put(alertsMonitoringData.receive(action.payload, data));
    }
  } catch (error) {
    log(`error looking up path=${req} status=${error.message}`);
  }
}

export function* historySaga(): Generator<*, *, *> {
  yield fork(function* () { yield* takeEvery(ALERTS_REQUEST_HISTORY, fetchHistorySaga); });
  yield fork(function* () { yield* takeEvery(ALERTS_REQUEST_MONITORING_DATA, fetchMonitoringData); });
}

export default historySaga;
