// @flow
// (Copyright) [2016 - 2016] Confluent, Inc.
import debug from 'debug';
import { call, fork, put } from 'redux-saga/effects';
import { takeLatest } from 'redux-saga';

import * as ConnectorPluginActions from 'actions/connectorPlugins';
import { putJson } from 'actions/util';

import type {
  ConnectorPluginValidationResponse,
  ValidateConfigAction
} from 'actions/connectorPlugins';

const log = debug('controlcenter:sagas:management:connectorPlugins');

export function* validateConfig(action: ValidateConfigAction): Generator<*, *, *> {
  const { config } = action.payload;
  const { name } = config;

  if (!config['connector.class']) {
    return;
  }

  const reqPath = `/2.0/management/connect/connector-plugins/${encodeURIComponent(config['connector.class'])}/config/validate`;

  yield put(ConnectorPluginActions.validate.request(name, config));

  try {
    const validationData: any | ConnectorPluginValidationResponse = yield call(putJson, reqPath, config);
    yield put(ConnectorPluginActions.validate.success(name, validationData));
  } catch (error) {
    log(`error looking up path=${reqPath} status=${error.message}`);
    yield put(ConnectorPluginActions.validate.failure(name, error));
  }
}

export function* validateConfigSaga(): Generator<*, *, *> {
  yield call(takeLatest, ConnectorPluginActions.CONNECTOR_PLUGINS_VALIDATE_CONFIG, validateConfig);
}

export function* connectorPluginsSaga(): Generator<*, *, *> {
  yield fork(validateConfigSaga);
}

export default connectorPluginsSaga;
