// @flow
// (Copyright) [2016 - 2016] Confluent, Inc.

export const MemberTitleIconTypes = {
  PRODUCER: 'PRODUCER',
  CONSUMER_GROUP: 'CONSUMER_GROUP',
  TOPIC: 'TOPIC'
};

export type MemberTitleIconType = $Enum<typeof MemberTitleIconTypes>;

// d3 scale can take either a Date object or a number
// (unix time, milliseconds) and it'll work. we use both.
export type TimeScale = (dateTime: Date | number) => number;
export type NumberScale = (val: number) => number;

export type SlotWidth = {
  ms: number,
  px: number
};

export type TimeSpan = {
  startTime: Date,
  endTime: Date
};

export const Rollups = {
  FIFTEEN_SECONDS: 'FIFTEEN_SECONDS',
  ONE_HOUR: 'ONE_HOUR',
  ONE_WEEK: 'ONE_WEEK',
  toMs: (rollup: Rollup): number => {
    switch (rollup) {
      case 'ONE_WEEK':
        return 7*24*60*60*1000;
      case 'ONE_HOUR':
        return 60*60*1000;
      case 'FIFTEEN_SECONDS':
      default:
        return 15*1000;
    }
  }
};

export type Rollup = $Enum<typeof Rollups>;

export type FixedTimeRangeSpec = {
  rangeType: 'FIXED',
  startTimeMs: number,
  stopTimeMs: number
};

export type RollingTimeRangeSpec = {
  rangeType: 'ROLLING',
  lengthMs: number
};

export type GrowingTimeRangeSpec = {
  rangeType: 'GROWING_DAY' | 'GROWING_WEEK' | 'GROWING_MONTH'
};

export type TimeRangeSpec = FixedTimeRangeSpec | RollingTimeRangeSpec | GrowingTimeRangeSpec;

export const MonitoringDataTypes = {
  DELIVERY: 'DELIVERY',
  LATENCY: 'LATENCY'
};

export type MonitoringDataType = $Enum<typeof MonitoringDataTypes>;
