// @flow
// (Copyright) [2016 - 2016] Confluent, Inc.
import debug from 'debug';
import { timeFormat } from 'd3-time-format';

const log = debug('controlcenter:assert');

export function assert(condition: boolean, message: string) {
  if (process.env.NODE_ENV !== 'production') {
    if (!condition) {
      throw new Error(message);
    }
  } else {
    log(message);
  }
}

export function sumArrayUntil(list: Array<?number>, lastIndexToInclude: number): number {
  let sum = 0;
  for (let i=0; i<list.length && i <= lastIndexToInclude; ++i) {
    if (list[i]) {
      sum += list[i];
    }
  }
  return sum;
}

export const rangeLimit = (x: number, max: number): number => Math.min(Math.max(x, 0), max);

export const dropLeadingZero = (str: string): string => str.startsWith('0') ? str.substr(1) : str;

export const formatTime = (dateMs: ?number): string =>
  dateMs == null ? '' : dropLeadingZero(timeFormat('%I:%M:%S%p')(dateMs).toLowerCase());
