// @flow
// (Copyright) [2016 - 2016] Confluent, Inc.
import { pick, omit, get } from 'lodash';

type RouteEnterParamFilteringHandler = (prevState: Object, nextState: Object, replace: Function) => any;

export const handleRouteEnterParamFiltering: RouteEnterParamFilteringHandler = (prevState, nextState, replace) => {

  const whitelist = nextState.routes.reduce((total, route) => {
    if (Array.isArray(route.queryParamsWhitelist)) {
      return [
        ...total,
        ...route.queryParamsWhitelist
      ];
    }
    return total;
  }, []);

  // this lets us get back to default, non-retaining qp behavior if needed
  const existingQueryParamBlacklist = get(nextState.location, ['state', 'existingQueryParamBlacklist'], []);

  const hasUnwantedParams = Object.keys(nextState.location.query).some(qp => !whitelist.includes(qp));

  // retain query params that are in the filter
  const nextQuery = pick(nextState.location.query, whitelist);
  const prevQuery = omit(pick(prevState.location.query, whitelist), existingQueryParamBlacklist);

  // did the last state have something useful that we can keep?
  const prevQueryIsUseful = Object.keys(prevQuery).some(key => !(key in nextState.location.query));

  if (hasUnwantedParams || prevQueryIsUseful) {
    replace({
      ...nextState.location,
      query: {
        ...prevQuery,
        ...nextQuery
      }
    });
  }
};
