// @flow
// (Copyright) [2016 - 2016] Confluent, Inc.
import React from 'react';
import { shallow } from 'enzyme';

import {
  AggregateConsumption,
  calculateAggregateConsumption,
  calculateConsumptionWarning
} from 'components/aggregate-stats/AggregateConsumption';

import styles from 'components/aggregate-stats/AggregateStats.css';

describe('#calculateAggregateConsumption', () => {
  it('returns overall consumption', () => {
    const val1 = calculateAggregateConsumption(
      {
        startTimeMs: 0,
        stepMs: 15000,
        values: [20, 20, 20, 20, 20]
      },
      {
        startTimeMs: 0,
        stepMs: 15000,
        values: [20, 20, 20, 19, 20]
      },
      Infinity
    );

    const val2 = calculateAggregateConsumption(
      {
        startTimeMs: 0,
        stepMs: 15000,
        values: [678, 678, 678, 678, 678, 678]
      },
      {
        startTimeMs: 0,
        stepMs: 15000,
        values: [678, 678, 678, 678, 678, 678]
      }, Infinity);

    expect(val1).to.not.be.null;
    expect(val2).to.not.be.null;
    if (val1 != null && val2 != null) {
      expect(`${val1.toFixed(2)}`).to.eql('99.00');
      expect(`${val2.toFixed(2)}`).to.eql('100.00');
    }
  });
});

describe('#calculateConsumptionWarning', () => {
  it('returns consumption warning message', () => {
    const val1 = calculateConsumptionWarning(
      {
        startTimeMs: 0,
        stepMs: 15000,
        values: [10, 10, 10, 10, 11, 10]
      },
      {
        startTimeMs: 0,
        stepMs: 0,
        values: [10, 10, 10, 10, 10, 10]
      },
      Infinity
    );

    const val2 = calculateConsumptionWarning(
      {
        startTimeMs: 0,
        stepMs: 15000,
        values: [20, 20, 20, 30]
      },
      {
        startTimeMs: 0,
        stepMs: 15000,
        values: [30, 30, 30, 20]
      },
      Infinity
    );

    expect(val1).to.not.be.null;
    expect(val2).to.not.be.null;
    if (val1 != null && val2 != null) {
      expect(val1).to.eql('Under consumption has been detected during this time window.');
      expect(val2).to.eql('Over and under consumption have been detected during this time window.');
    }
  });
});


describe('<AggregateConsumption />', () => {
  it('renders', () => {
    const aggregateConsumption = 61;
    const consumptionWarning = 'Is borked...';

    const wrapper = shallow(
      <AggregateConsumption
        aggregateConsumption={aggregateConsumption}
        consumptionWarning={consumptionWarning}
      />
    );
    expect(wrapper.find({ className: styles['item-warn'] })).to.have.length(1);
    expect(wrapper.find({ className: styles['item-stat'] })).to.have.length(1);
  });
});
