// @flow
// (Copyright) [2016 - 2016] Confluent, Inc.
import React from 'react';
import { mount } from 'enzyme';
import addIcon from 'static/icons/add.svg';

import styles from 'components/button/Button.css';
import {
  Button,
  ButtonPrimaryLarge,
  ButtonPrimaryMedium,
  ButtonSecondaryLarge,
  ButtonSecondaryMedium,
  ButtonSizes,
  ButtonClassTypes
} from 'components/button/Button';

describe('components/button', () => {
  const { MEDIUM } = ButtonSizes;
  const { PRIMARY } = ButtonClassTypes;

  describe('<Button />', () => {
    it('mounts', () => {
      const wrapper = mount(<Button />);

      expect(wrapper).to.be.present();
      wrapper.unmount();
    });

    it('displays size medium and type primary by default', () => {
      const wrapper = mount(<Button />);

      expect(wrapper.find({ className: styles['button-primary-medium'] })).to.be.present();
      expect(wrapper.props()).to.deep.equal({
        classType: PRIMARY,
        size: MEDIUM
      });
      wrapper.unmount();
    });

    it('.text only renders when there is text content', () => {
      const wrapperWithoutText = mount(<Button text="plz don't click me!!!" />);
      expect(wrapperWithoutText.find({ className: styles.text })).to.be.present();
      wrapperWithoutText.unmount();

      const wrapperWithText = mount(<Button />);
      expect(wrapperWithText.find({ className: styles.text })).to.not.be.present();
      wrapperWithText.unmount();
    });

    it('.icon only renders when there is a provided icon', () => {
      const wrapperWithoutIcon = mount(<Button icon={addIcon} />);
      expect(wrapperWithoutIcon.find({ className: styles.icon })).to.be.present();
      wrapperWithoutIcon.unmount();

      const wrapperWithIcon = mount(<Button />);
      expect(wrapperWithIcon.find({ className: styles.icon })).to.not.be.present();
      wrapperWithIcon.unmount();
    });
  });

  describe('<ButtonPrimaryMedium />', () => {
    it('mounts', () => {
      const wrapper = mount(<ButtonPrimaryMedium />);
      expect(wrapper).to.be.present();
      wrapper.unmount();
    });

    it('displays size medium and type primary by default', () => {
      const wrapper = mount(<ButtonPrimaryMedium />);
      expect(wrapper.find({ className: styles['button-primary-medium'] })).to.be.present();
      wrapper.unmount();
    });
  });

  describe('<ButtonPrimaryLarge />', () => {
    it('mounts', () => {
      const wrapper = mount(<ButtonPrimaryMedium />);

      expect(wrapper).to.be.present();
      wrapper.unmount();
    });

    it('displays size large and type primary by default', () => {
      const wrapper = mount(<ButtonPrimaryLarge />);
      expect(wrapper.find({ className: styles['button-primary-large'] })).to.be.present();
      wrapper.unmount();
    });
  });

  describe('<ButtonSecondaryMedium />', () => {
    it('mounts', () => {
      const wrapper = mount(<ButtonSecondaryMedium />);
      expect(wrapper).to.be.present();
      wrapper.unmount();
    });

    it('displays size medium and type secondary by default', () => {
      const wrapper = mount(<ButtonSecondaryMedium />);
      expect(wrapper.find({ className: styles['button-secondary-medium'] })).to.be.present();
      wrapper.unmount();
    });
  });

  describe('<ButtonSecondaryLarge />', () => {
    it('mounts', () => {
      const wrapper = mount(<ButtonSecondaryLarge />);

      expect(wrapper).to.be.present();

      wrapper.unmount();
    });

    it('displays size medium and type primary by default', () => {
      const wrapper = mount(<ButtonSecondaryLarge />);
      expect(wrapper.find({ className: styles['button-secondary-large'] })).to.be.present();
      wrapper.unmount();
    });
  });
});
