// @flow
// (Copyright) [2016 - 2016] Confluent, Inc.
import { expect } from 'chai';
import React from 'react';
import { shallow } from 'enzyme';
import d3scale from 'd3-scale';

import AreaLineChart from 'components/charting/charts/area-line-chart';
import ChartArea from 'components/charting/charts/ChartArea';

import { createAxisCountTextFormatter } from 'components/charting/charts/area-line-chart/AreaLineChart';


describe('createAxisCountTextFormatter', () => {
  it('100s', () => {
    const gridLines = [
      { y: 0 },
      { y: 100 },
      { y: 200 },
      { y: 300 }
    ];
    const formatter = createAxisCountTextFormatter(gridLines);
    expect(formatter(0)).to.eql('0');
    expect(formatter(100)).to.eql('100');
  });

  it('1000s', () => {
    const gridLines = [
      { y: 2000 },
      { y: 3000 }
    ];
    const formatter = createAxisCountTextFormatter(gridLines);
    expect(formatter(0)).to.eql('0');
    expect(formatter(1000)).to.eql('1k');
  });

  it('1000s 1 decimal place', () => {
    const gridLines = [
      { y: 2000 },
      { y: 2100 },
      { y: 2200 }
    ];
    const formatter = createAxisCountTextFormatter(gridLines);
    expect(formatter(2000)).to.eql('2.0k');
    expect(formatter(2100)).to.eql('2.1k');
  });

  it('1000s 2 decimal places', () => {
    const gridLines = [
      { y: 2000 },
      { y: 2050 },
      { y: 2100 }
    ];
    const formatter = createAxisCountTextFormatter(gridLines);
    expect(formatter(2000)).to.eql('2.00k');
    expect(formatter(2050)).to.eql('2.05k');
    expect(formatter(2100)).to.eql('2.10k');
  });

  it('1Ms', () => {
    const gridLines = [
      { y: 2000000 },
      { y: 3000000 }
    ];
    const formatter = createAxisCountTextFormatter(gridLines);
    expect(formatter(0)).to.eql('0');
    expect(formatter(1000000)).to.eql('1M');
  });

  it('1Ms 3 decimal places', () => {
    const gridLines = [
      { y: 2123000 },
      { y: 2124000 }
    ];
    const formatter = createAxisCountTextFormatter(gridLines);
    expect(formatter(0)).to.eql('0');
    expect(formatter(2125000)).to.eql('2.125M');
  });

});


describe('<AreaLineChart />', () => {
  const xScale = d3scale.scaleTime().domain([0, 100]).range([0, 100]);

  it('renders', () => {
    const wrapper = shallow(
      <AreaLineChart
        lineData={null}
        areaData={null}
        xScale={xScale}
        height={100}
        slotWidth={{ ms: 1, px: 10 }}
        mouseOverTime={null}
        hoverFormatter={null}
        legend={null}
        title={null}
        titleIconType={null}
        disabled={false}
      />
    );
    expect(wrapper).to.be.present();
    expect(wrapper.find(ChartArea)).to.have.length(1);
  });

});
