// @flow
// (Copyright) [2016 - 2016] Confluent, Inc.
import { expect } from 'chai';
import React from 'react';
import { shallow } from 'enzyme';
import d3scale from 'd3-scale';

import AreaLineChartInner from 'components/charting/charts/area-line-chart/AreaLineChartInner';
import FillGradient from 'components/charting/charts/FillGradient';


import type {
  TimeSeries
} from 'types/monitoring/data';

const fakeLineData: TimeSeries = {
  startTimeMs: 0,
  stepMs: 1,
  values: [5, 10, 5, 5]
};

const goodFakeAreaData: TimeSeries = fakeLineData;

const badFakeAreaData: TimeSeries = {
  startTimeMs: 0,
  stepMs: 1,
  values: [5, 5, 5, 5]
};

describe('<AreaLineChartInner />', () => {

  const xScale = d3scale.scaleTime().domain([0, 100]).range([0, 100]);
  const yScale = d3scale.scaleLinear().domain([0, 20]).range([0, 100]);

  it('renders good data', () => {

    const wrapper = shallow(
      <AreaLineChartInner
        lineSlotData={fakeLineData}
        areaSlotData={goodFakeAreaData}
        slotWidth={{ ms: 1, px: 4 }}
        xScale={xScale}
        yScale={yScale}
        missingRegions={[]}
        applyIgnoreFailureHeuristic={false}
      />
    );
    expect(wrapper).to.be.present();

    expect(wrapper.find(FillGradient)).to.have.length(3);
    expect(wrapper.find('polyline')).to.have.length(2);
  });

  it('renders bad data', () => {

    const wrapper = shallow(
      <AreaLineChartInner
        lineSlotData={fakeLineData}
        areaSlotData={badFakeAreaData}
        slotWidth={{ ms: 1, px: 4 }}
        xScale={xScale}
        yScale={yScale}
        missingRegions={[]}
        applyIgnoreFailureHeuristic={false}
      />
    );
    expect(wrapper).to.be.present();

    expect(wrapper.find(FillGradient)).to.have.length(3);
    expect(wrapper.find('polyline')).to.have.length(4);
  });

});
