// @flow
// (Copyright) [2016 - 2016] Confluent, Inc.
import { expect } from 'chai';
import React from 'react';
import { shallow } from 'enzyme';
import d3scale from 'd3-scale';

import RangeChart from 'components/charting/charts/range-chart';
import { createAxisDurationTextFormatter } from 'components/charting/charts/range-chart/RangeChart';

describe('createAxisTextFormatter', () => {
  it('100s', () => {
    const formatter = createAxisDurationTextFormatter();
    expect(formatter(0)).to.eql('0');
    expect(formatter(100)).to.eql('100ms');
    expect(formatter(1000)).to.eql('1s');
    expect(formatter(1500)).to.eql('1.5s');
    expect(formatter(86400000)).to.eql('86400s');
  });
});

describe('RangeChart', () => {
  it('renders', () => {
    const xScale = d3scale.scaleTime().domain([0, 1]).range([0, 1]);
    const wrapper = shallow(
      <div>
        <RangeChart
          data={{
            startTimeMs: 0,
            stepMs: 15000,
            values: {
              totalLatency: [],
              count: [],
              minLatency: [],
              maxLatency: []
            } }}
          xScale={xScale}
          height={100}
          slotWidth={{ ms: 1000, px: 4 }}
          legend={null}
          mouseOverTime={null}
          disabled={false}
        />
      </div>
    );
    expect(wrapper).to.be.present();
  });
});
