// @flow
// (Copyright) [2016 - 2016] Confluent, Inc.

import { linkSpecToDisplaySpec } from 'components/charting/popup/linkSpecUtil';


describe('linkSpecToDisplaySpec', () => {

  it('null', () => {
    const displaySpec = linkSpecToDisplaySpec(null);
    expect(displaySpec).to.be.null;
  });

  it('garbage in, nothing out', () => {
    const displaySpec = linkSpecToDisplaySpec({ trump: '2016' });
    expect(displaySpec).to.be.null;
  });

  it('topic partition', () => {
    const displaySpec = linkSpecToDisplaySpec({ topic: 'division by two', partition: 138 });
    expect(displaySpec).to.not.be.null;
    if (!displaySpec) return;
    expect(displaySpec.path).to.be.null;
    expect(displaySpec.parts).to.have.length(1);
    expect(displaySpec.parts[0].type).to.eql('TOPIC PARTITION');
    expect(displaySpec.parts[0].name).to.eql('division by two: 138');
  });

  it('topic', () => {
    const displaySpec = linkSpecToDisplaySpec({ topic: 'life the universe and kafka' });
    expect(displaySpec).to.not.be.null;
    if (!displaySpec) return;
    expect(displaySpec.path).to.be.null;
    expect(displaySpec.parts).to.have.length(1);
    expect(displaySpec.parts[0].type).to.eql('TOPIC');
    expect(displaySpec.parts[0].name).to.eql('life the universe and kafka');
  });

  it('client', () => {
    const displaySpec = linkSpecToDisplaySpec({ clientId: 'u-bute big data services' });
    expect(displaySpec).to.not.be.null;
    if (!displaySpec) return;
    expect(displaySpec.path).to.eql('/monitoring/consumers/u-bute%20big%20data%20services');
    expect(displaySpec.parts).to.have.length(1);
    expect(displaySpec.parts[0].type).to.eql('CLIENT');
    expect(displaySpec.parts[0].name).to.eql('u-bute big data services');
  });

  it('group', () => {
    const displaySpec = linkSpecToDisplaySpec({ group: 'aa.org' });
    expect(displaySpec).to.not.be.null;
    if (!displaySpec) return;
    expect(displaySpec.path).to.eql('/monitoring/consumer-groups/aa.org');
    expect(displaySpec.parts).to.have.length(1);
    expect(displaySpec.parts[0].type).to.eql('CONSUMER GROUP');
    expect(displaySpec.parts[0].name).to.eql('aa.org');
  });

});

