// @flow
// (Copyright) [2016 - 2016] Confluent, Inc.
import React from 'react';
import { mount, shallow } from 'enzyme';

import styles from 'components/layout/ContentPanel.css';
import { ContentPanel } from 'components/layout/ContentPanel';

describe('<ContentPanel />', () => {
  it('mounts', () => {
    const props = {
      hasError: false
    };
    const wrapper = mount(<ContentPanel {...props} />);
    expect(wrapper).to.be.present();
    wrapper.unmount();
  });

  describe('`hasError`', () => {
    it('uses error class when true', () => {
      const props = {
        hasError: true
      };
      const wrapper = shallow(<ContentPanel {...props} />);
      expect(wrapper).to.be.present();
      expect(wrapper.find({
        className: styles['content-panel-root-error']
      })).to.be.present();
    });
  });

  describe('`width` and `height`', () => {
    it('passes height to child as a style', () => {
      const props = {
        height: 50
      };
      const wrapper = shallow(<ContentPanel {...props} />);
      expect(wrapper).to.be.present();

      expect(wrapper.find({
        style: {
          height: 50
        }
      })).to.be.present();
    });

    it('passes width to child as a style', () => {
      const props = {
        width: 19
      };
      const wrapper = shallow(<ContentPanel {...props} />);
      expect(wrapper).to.be.present();

      expect(wrapper.find({
        style: {
          width: 19
        }
      })).to.be.present();
    });

    it('passes both width and height to child as a style', () => {
      const props = {
        height: 50,
        width: 19
      };
      const wrapper = shallow(<ContentPanel {...props} />);
      expect(wrapper).to.be.present();

      expect(wrapper.find({
        style: {
          height: 50,
          width: 19
        }
      })).to.be.present();
    });
  });
});
