// @flow
// (Copyright) [2016 - 2016] Confluent, Inc.
import React from 'react';
import moment from 'moment';
import { shallow } from 'enzyme';
import styles from 'components/license-countdown/LicenseCountdown.css';
import {
  LicenseCountdown,
  select,
  LABEL_MISSING,
  LABEL_FUTURE,
  LABEL_PAST
} from 'components/license-countdown/LicenseCountdown';

describe('<LicenseCountdown />', () => {
  it('renders', () => {
    const wrapper = shallow(<LicenseCountdown label="label" value="value" />);
    expect(wrapper.find({ className: styles['license-info-root'] })).to.be.present();
  });

  it('handles missing data', () => {
    const wrapper = shallow(<LicenseCountdown label="label" value="value" />);
    const label = wrapper.find({ className: styles['license-label'] });
    expect(label).to.be.present();
    expect(label.text()).to.equal('label');
    const value = wrapper.find({ className: styles['license-value'] });
    expect(value).to.be.present();
    expect(value.text()).to.equal('value');
  });

  it('select should handle missing data', () => {
    const props = select({ license: {} });
    expect(props.label).to.equal(LABEL_MISSING);
  });

  it('select should handle future epiration', () => {
    const props = select({ license: { expiration: moment().add(1, 'day') } });
    expect(props.label).to.equal(LABEL_FUTURE);
  });
  it('select should handle already being expired', () => {
    const props = select({ license: { expiration: moment().subtract(1, 'day') } });
    expect(props.label).to.equal(LABEL_PAST);
  });
});
