// @flow
// (Copyright) [2016 - 2016] Confluent, Inc.
import React from 'react';
import { shallow } from 'enzyme';

import { Monitoring, timeframeSpecFromQueryParams } from 'components/monitoring/Monitoring';
import { Header } from 'components/header';

import { setTimeRange, updateEndTime } from 'actions/monitoring/timeframe';
import { RangeTypes } from 'constants/monitoring/timeframe';


describe('<Monitoring />', () => {
  it('renders', () => {
    const wrapper = shallow(<Monitoring params={{ id: null }} location={{ query: { rtr: 5 } }} setTimeRange={setTimeRange} updateEndTime={updateEndTime} />);
    expect(wrapper).to.be.present();
    wrapper.unmount();
  });

  it('renders one <Header />', () => {
    const wrapper = shallow(<Monitoring params={{ id: null }} location={{ query: { rtr: 5 } }} setTimeRange={setTimeRange} updateEndTime={updateEndTime} />);
    expect(wrapper.find(Header)).to.be.present();
    wrapper.unmount();
  });

  it('timeframeSpecFromQueryParams g day', () => {
    const params = { g: 'day' };
    const result = timeframeSpecFromQueryParams(params);
    expect(result).to.not.be.null;
    if (result != null) {
      expect(result).to.have.property('rangeType');
      expect(result.rangeType).to.eql(RangeTypes.GROWING_DAY);
    }
  });

  it('timeframeSpecFromQueryParams g week', () => {
    const params = { g: 'week' };
    const result = timeframeSpecFromQueryParams(params);
    expect(result).to.not.be.null;
    if (result != null) {
      expect(result).to.have.property('rangeType');
      expect(result.rangeType).to.eql(RangeTypes.GROWING_WEEK);
    }
  });

  it('timeframeSpecFromQueryParams g month', () => {
    const params = { g: 'month' };
    const result = timeframeSpecFromQueryParams(params);
    expect(result).to.not.be.null;
    if (result != null) {
      expect(result).to.have.property('rangeType');
      expect(result.rangeType).to.eql(RangeTypes.GROWING_MONTH);
    }
  });

  it('timeframeSpecFromQueryParams growing day', () => {
    const params = { growing: 'day' };
    const result = timeframeSpecFromQueryParams(params);
    expect(result).to.not.be.null;
    if (result != null) {
      expect(result).to.have.property('rangeType');
      expect(result.rangeType).to.eql(RangeTypes.GROWING_DAY);
    }
  });

  it('timeframeSpecFromQueryParams growing week', () => {
    const params = { growing: 'week' };
    const result = timeframeSpecFromQueryParams(params);
    expect(result).to.not.be.null;
    if (result != null) {
      expect(result).to.have.property('rangeType');
      expect(result.rangeType).to.eql(RangeTypes.GROWING_WEEK);
    }
  });

  it('timeframeSpecFromQueryParams growing month', () => {
    const params = { growing: 'month' };
    const result = timeframeSpecFromQueryParams(params);
    expect(result).to.not.be.null;
    if (result != null) {
      expect(result).to.have.property('rangeType');
      expect(result.rangeType).to.eql(RangeTypes.GROWING_MONTH);
    }
  });

  it('timeframeSpecFromQueryParams r', () => {
    const params = { r: '10' };
    const result = timeframeSpecFromQueryParams(params);
    expect(result).to.not.be.null;
    if (result != null) {
      expect(result).to.have.property('rangeType');
      expect(result.rangeType).to.eql(RangeTypes.ROLLING);
      expect(result.lengthMs).to.eql(10*60*1000);
    }
  });

  it('timeframeSpecFromQueryParams rolling', () => {
    const params = { rolling: '10' };
    const result = timeframeSpecFromQueryParams(params);
    expect(result).to.not.be.null;
    if (result != null) {
      expect(result).to.have.property('rangeType');
      expect(result.rangeType).to.eql(RangeTypes.ROLLING);
      expect(result.lengthMs).to.eql(10*60*1000);
    }
  });

  it('timeframeSpecFromQueryParams s e', () => {
    const params = { s: '10', e: '20' };
    const result = timeframeSpecFromQueryParams(params);
    expect(result).to.not.be.null;
    if (result != null) {
      expect(result).to.have.property('rangeType');
      expect(result.rangeType).to.eql(RangeTypes.FIXED);
      expect(result.startTimeMs).to.eql(10);
      expect(result.stopTimeMs).to.eql(20);
    }
  });

  it('timeframeSpecFromQueryParams fixed', () => {
    const params = { 'fixed-start': '10', 'fixed-end': '20' };
    const result = timeframeSpecFromQueryParams(params);
    expect(result).to.not.be.null;
    if (result != null) {
      expect(result).to.have.property('rangeType');
      expect(result.rangeType).to.eql(RangeTypes.FIXED);
      expect(result.startTimeMs).to.eql(10);
      expect(result.stopTimeMs).to.eql(20);
    }
  });

});
