// @flow
// (Copyright) [2016 - 2016] Confluent, Inc.
import React from 'react';
import { mount } from 'enzyme';
import moment from 'moment';

import { Clock, nextHour, nextMinute, nextAmPm } from 'components/time-picker/Clock';
import styles from 'components/time-picker/Clock.css';

const testTimestamp = 1457133655; // March 4, 2016 3:20pm

describe('<Clock />', () => {
  it('renders', () => {
    const wrapper = mount(<Clock currTime={testTimestamp} onDateChange={() => {}} />);
    expect(wrapper.find({ className: styles['clock-root'] })).to.be.present();
    expect(wrapper.find({ className: styles['options'] })).to.have.length(3);
    expect(wrapper.find({ className: styles['option'] })).to.have.length(9);
    expect(wrapper.find({ className: styles['option'] }).nodes[0].innerHTML).to.equal('4');
    expect(wrapper.find({ className: styles['option'] }).nodes[1].innerHTML).to.equal('3');
    expect(wrapper.find({ className: styles['option'] }).nodes[2].innerHTML).to.equal('2');
    expect(wrapper.find({ className: styles['option'] }).nodes[3].innerHTML).to.equal('21');
    expect(wrapper.find({ className: styles['option'] }).nodes[4].innerHTML).to.equal('20');
    expect(wrapper.find({ className: styles['option'] }).nodes[5].innerHTML).to.equal('19');
    expect(wrapper.find({ className: styles['option'] }).nodes[6].innerHTML).to.equal('AM');
    expect(wrapper.find({ className: styles['option'] }).nodes[7].innerHTML).to.equal('PM');
    expect(wrapper.find({ className: styles['option'] }).nodes[8].innerHTML).to.equal('AM');
  });
});

describe('#nextHour', () => {
  it('provides appropriate hours', () => {
    let newTime = nextHour(-1, testTimestamp);
    expect(moment.unix(newTime).format('h')).to.equal('2');

    newTime = nextHour(-99, testTimestamp);
    expect(moment.unix(newTime).format('h')).to.equal('12');

    newTime = nextHour(99, testTimestamp);
    expect(moment.unix(newTime).format('h')).to.equal('1');
  });
});

describe('#nextMinute', () => {
  it('provides appropriate hours', () => {
    let newTime = nextMinute(5, testTimestamp);
    expect(moment.unix(newTime).format('m')).to.equal('25');

    newTime = nextMinute(-99, testTimestamp);
    expect(moment.unix(newTime).format('m')).to.equal('59');

    newTime = nextMinute(99, testTimestamp);
    expect(moment.unix(newTime).format('m')).to.equal('0');
  });
});

describe('#nextAmPm', () => {
  it('provides appropriate hours', () => {
    let newTime = nextAmPm(testTimestamp);
    expect(moment.unix(newTime).format('A')).to.equal('AM');
    newTime = nextAmPm(newTime);
    expect(moment.unix(newTime).format('A')).to.equal('PM');
  });
});
