// @flow
// (Copyright) [2016 - 2016] Confluent, Inc.
import React from 'react';
import { shallow, mount } from 'enzyme';
import sinon from 'sinon';

import styles from 'components/time-picker/MainControls.css';
import MainControls from 'components/time-picker/MainControls';
import { PickerTargets } from 'constants/timePicker';
import { ButtonClassTypes } from 'components/button';

describe('<MainControls />', () => {
  const defaultProps = {
    startDayButtonType: ButtonClassTypes.SECONDARY,
    startTimeButtonType: ButtonClassTypes.SECONDARY,
    endDayButtonType: ButtonClassTypes.SECONDARY,
    endTimeButtonType: ButtonClassTypes.SECONDARY,
    startTime: 0,
    endTime: 100,
    onHandleMenuButtonClick: () => 0
  };
  it('renders', () => {
    const wrapper = shallow(
      <MainControls {...defaultProps} />
    );
    expect(wrapper.find({ className: styles['main-controls-root'] })).to.be.present();
  });

  describe('handles button clicks', () => {
    let onClick;
    let wrapper;
    beforeEach(() => {
      onClick = sinon.spy();
      wrapper = mount(
        <MainControls
          {...defaultProps}
          onHandleMenuButtonClick={onClick}
        />
      );
    });

    it('start day', () => {
      wrapper.find({ className: styles['inner'] }).childAt(0).simulate('click');
      expect(onClick.calledOnce).to.equal(true);
      expect(onClick.calledWithExactly(PickerTargets.START_DAY)).to.equal(true);
    });

    it('start time', () => {
      wrapper.find({ className: styles['inner'] }).childAt(1).simulate('click');
      expect(onClick.calledOnce).to.equal(true);
      expect(onClick.calledWithExactly(PickerTargets.START_TIME)).to.equal(true);
    });

    it('end day', () => {
      wrapper.find({ className: styles['inner'] }).childAt(3).simulate('click');
      expect(onClick.calledOnce).to.equal(true);
      expect(onClick.calledWithExactly(PickerTargets.END_DAY)).to.equal(true);
    });

    it('end time', () => {
      wrapper.find({ className: styles['inner'] }).childAt(4).simulate('click');
      expect(onClick.calledOnce).to.equal(true);
      expect(onClick.calledWithExactly(PickerTargets.END_TIME)).to.equal(true);
    });
  });
});
