// @flow
// (Copyright) [2016 - 2016] Confluent, Inc.
import React from 'react';
import { mount } from 'enzyme';
import moment from 'moment';
import { RangeTypes } from 'constants/monitoring/timeframe';

import { TimePicker, getPickerLabel, getRangeLabel } from 'components/time-picker/TimePicker';
import { defaultGetRanges } from 'components/time-picker/DefaultRanges';
import styles from 'components/time-picker/TimePicker.css';

const testTimestamp = 1457133655; // March 4, 2016 3:20pm

describe('<TimePicker />', () => {
  it('renders', () => {
    const wrapper = mount(<TimePicker />);
    expect(wrapper.find({ className: styles['time-picker-root'] })).to.be.present();
    wrapper.unmount();
  });

  describe('#getPickerLabel', () => {
    it('provides appropiate rolling range label for picker', () => {
      const label = getPickerLabel(
        testTimestamp,
        testTimestamp,
        RangeTypes.ROLLING
      );
      expect(label).to.eql('Mar, 4 - Last a few seconds');

      const label2 = getPickerLabel(
        testTimestamp,
        moment.unix(testTimestamp).subtract(1, 'weeks').unix(),
        RangeTypes.ROLLING
      );
      expect(label2).to.eql('Feb, 26 - Last 7 days');
    });

    it('provides appropiate static range label for picker', () => {
      const label = getPickerLabel(
        testTimestamp,
        moment.unix(testTimestamp).subtract(3, 'days').unix(),
        RangeTypes.FIXED
      );
      expect(label).to.eql('Mar, 4 - Mar, 1');
    });

    it('provides appropiate growingWeek range label for picker', () => {
      const label = getPickerLabel(
        testTimestamp,
        moment.unix(testTimestamp).subtract(3, 'days').unix(),
        RangeTypes.GROWING_WEEK
      );
      expect(label).to.eql('Mar, 4 3:20 pm - Mar, 1 3:20 pm');
    });

    describe('#getRangeLabel', () => {
      const defaultRanges = defaultGetRanges();
      const expectedLabels = [
        'Last 10 minutes',
        'Last 30 minutes',
        'Last 4 hours',
        'Last 12 hours',
        'Last 24 hours',
        'Yesterday',
        'Today',
        'This week',
        'This month',
        ['Month so far', 'Week so far', 'Day so far'],
        ['Month so far', 'Week so far'],
        'Month so far',
        'Today last week',
        'Today last month'
      ];
      let i = 0;

      it('provides appropiate rolling range label', () => {
        defaultRanges.forEach((ranges) => {
          ranges.forEach((range) => {
            const label = getRangeLabel(
              range.startTime,
              range.endTime,
              range.rangeType
            );
            if (Array.isArray(expectedLabels[i])) {
              expect(expectedLabels[i]).to.include(label);
            } else {
              expect(label).to.eql(expectedLabels[i]);
            }
            i++;
          });
        });
      });
    });
  });
});
