// @flow
// (Copyright) [2016 - 2016] Confluent, Inc.

type CallCountType = {
  matched: number,
  unmatched: number
};

// TODO(mhowlett): something more complete. This is good enough for basic testing.
class XMLHttpRequestMock {

  path: ?string;
  readyState: number;
  status: number;
  responseText: ?string;
  onreadystatechange: () => void;
  onload: () => void;

  static routes: Array<Object> = [];
  static globalXMLHttpRequest: any;
  static callCount: CallCountType = { matched: 0, unmatched: 0 };
  static calledPaths: Object = {};
  static lastMethodCalled: ?string;

  constructor() {
    this.path = null;
    this.readyState = 0;
    this.status = -1;
    this.responseText = null;
  }

  static init(routes: Array<Object>) {
    XMLHttpRequestMock.callCount = {
      matched: 0,
      unmatched: 0
    };
    XMLHttpRequestMock.lastMethodCalled = null;
    XMLHttpRequestMock.calledPaths = {};
    XMLHttpRequestMock.globalXMLHttpRequest = XMLHttpRequest;
    XMLHttpRequestMock.routes = routes;
    // eslint-disable-next-line no-native-reassign
    XMLHttpRequest = XMLHttpRequestMock;
  }

  static restore() {
    // eslint-disable-next-line no-native-reassign
    XMLHttpRequest = XMLHttpRequestMock.globalXMLHttpRequest;
  }

  open(verb: string, path: string) {
    this.path = path;
    XMLHttpRequestMock.lastMethodCalled = verb;
  }

  send() {
    const info = XMLHttpRequestMock.routes.find(element => element.path === this.path);
    this.readyState = 4;

    if (info) {
      XMLHttpRequestMock.callCount.matched += 1;
      XMLHttpRequestMock.calledPaths[info.path] = true;
    } else {
      XMLHttpRequestMock.callCount.unmatched += 1;
    }

    this.status = info
      ? info.status
      : -1;

    this.responseText = info && info.body
      ? JSON.stringify(info.body)
      : null;

    if (this.onreadystatechange) {
      this.onreadystatechange();
    }

    if (this.status < 200 || this.status > 299) {
      return;
    }

    if (this.onload) {
      this.onload();
    }
  }

  setRequestHeader() {}

  static calls(): CallCountType {
    return XMLHttpRequestMock.callCount;
  }

  static lastMethod(): ?string {
    return XMLHttpRequestMock.lastMethodCalled;
  }

  static called(path: string): boolean {
    return XMLHttpRequestMock.calledPaths[path] && true;
  }
}

export default XMLHttpRequestMock;
