// @flow
// (Copyright) [2016 - 2016] Confluent, Inc.
import { triggerForm } from 'reducers/alerts/triggerForm';

import { SET_FORM_OPTIONS } from 'actions/form';
import { FormTypes } from 'types/form';
import { SelectOptionListIds } from 'types/alerts';


describe('triggerForm', () => {

  it('good default state', () => {
    const defaultState = triggerForm(undefined, { type: 'blah', payload: null });
    expect(defaultState).to.have.property('selectOptions');
    expect(defaultState.selectOptions).to.have.property(SelectOptionListIds.CONNECTORS);
    expect(defaultState.selectOptions).to.have.property(SelectOptionListIds.CONSUMER_GROUPS);
    expect(defaultState.selectOptions[SelectOptionListIds.CONNECTORS]).to.eql([]);
    expect(defaultState.selectOptions[SelectOptionListIds.CONSUMER_GROUPS]).to.eql([]);
  });

  it('setFormOptions (not relevant 1)', () => {
    const state = triggerForm(undefined, { type: null, payload: null });
    const updated = triggerForm(state, { type: SET_FORM_OPTIONS, payload: { formType: FormTypes.CONNECTOR_FORM, fieldName: SelectOptionListIds.CONNECTORS, options: ['c1', 'c2'] } });
    expect(updated.selectOptions[SelectOptionListIds.CONSUMER_GROUPS]).to.eql([]);
    expect(updated.selectOptions[SelectOptionListIds.CONNECTORS]).to.eql([]);
  });

  it('setFormOptions (not relevant 2)', () => {
    const state = triggerForm(undefined, { type: null, payload: null });
    const updated = triggerForm(state, { type: SET_FORM_OPTIONS, payload: { formType: FormTypes.ALERTS_TRIGGER_FORM, fieldName: 'errant', options: ['c1', 'c2'] } });
    expect(updated.selectOptions[SelectOptionListIds.CONSUMER_GROUPS]).to.eql([]);
    expect(updated.selectOptions[SelectOptionListIds.CONNECTORS]).to.eql([]);
  });

  it('setFormOptions (connectors)', () => {
    const state = triggerForm(undefined, { type: null, payload: null });
    const updated = triggerForm(state, { type: SET_FORM_OPTIONS, payload: { formType: FormTypes.ALERTS_TRIGGER_FORM, fieldName: SelectOptionListIds.CONNECTORS, options: [{ label: 'c1', value: '1' }, { label: 'c2', value: '2' }] } });
    expect(updated.selectOptions[SelectOptionListIds.CONSUMER_GROUPS]).to.eql([]);
    expect(updated.selectOptions[SelectOptionListIds.CONNECTORS]).to.eql([{ label: 'c1', value: '1' }, { label: 'c2', value: '2' }]);
  });

  it('setFormOptions (consumerGroups)', () => {
    const state = triggerForm(undefined, { type: null, payload: null });
    const updated = triggerForm(state, { type: SET_FORM_OPTIONS, payload: { formType: FormTypes.ALERTS_TRIGGER_FORM, fieldName: SelectOptionListIds.CONSUMER_GROUPS, options: [{ label: 'cg1', value: '1' }, { label: 'cg2', value: '2' }] } });
    expect(updated.selectOptions[SelectOptionListIds.CONSUMER_GROUPS]).to.eql([{ label: 'cg1', value: '1' }, { label: 'cg2', value: '2' }]);
    expect(updated.selectOptions[SelectOptionListIds.CONNECTORS]).to.eql([]);
  });

});

