// @flow
// (Copyright) [2016 - 2016] Confluent, Inc.
import layout from 'reducers/layout';

import type { Action } from 'types';

import {
    SET_FOCUSED_COMPONENT,
    UNSET_FOCUSED_COMPONENT,
    ComponentTypes
} from 'actions/layout';

describe('layout', () => {

  const setFocusedComponent: Action<*, *> = {
    type: SET_FOCUSED_COMPONENT,
    payload: {
      type: ComponentTypes.MONITORING_CHART,
      id: { componentId: 1, qualifier: 'blah' }
    }
  };

  const unsetFocusedComponent: Action<*, *> = {
    type: UNSET_FOCUSED_COMPONENT,
    payload: null
  };

  it('good default state', () => {
    const defaultLayout = layout(undefined, { type: ComponentTypes.MONITORING_CHART, payload: null });
    expect(defaultLayout).to.have.property('focusedComponent');
    expect(defaultLayout.focusedComponent).to.be.null;
  });

  it('setFocusedComponent', () => {
    const lo = layout(undefined, setFocusedComponent);
    expect(lo).to.have.property('focusedComponent');
    if (lo != null && lo.focusedComponent != null) {
      expect(lo.focusedComponent.type).to.eql(ComponentTypes.MONITORING_CHART);
      // $FlowFixMe
      expect(lo.focusedComponent.id).to.exist;
    }
  });

  it('unsetFocusedComponent', () => {
    const lo = layout(undefined, unsetFocusedComponent);
    expect(lo).to.have.property('focusedComponent');
    expect(lo.focusedComponent).to.be.null;
  });

});
