// @flow
// (Copyright) [2016 - 2016] Confluent, Inc.
import { layout } from 'reducers/monitoring/layout';

import {
  SET_TIME_PICKER_VISIBILITY,
  SET_CHART_AREA_WIDTH,
  SET_MOUSE_OVER_TIME
} from 'actions/monitoring/layout';

import type { Action } from 'types';

import { MIN_CHART_AREA_WIDTH_PX } from 'constants/monitoring/layout';

describe('layout', () => {
  const makeTimePickerVisible: Action<*, *> = {
    type: SET_TIME_PICKER_VISIBILITY,
    payload: {
      isVisible: true
    }
  };

  const setChartAreaWidth: Action<*, *> = {
    type: SET_CHART_AREA_WIDTH,
    payload: {
      widthPixels: 1293
    }
  };

  const setMouseOverTime: Action<*, *> = {
    type: SET_MOUSE_OVER_TIME,
    payload: {
      mouseOverTime: 90210
    }
  };

  it('good default state', () => {
    const defaultLayout = layout(undefined, { type: 'blah', payload: null });
    expect(defaultLayout).to.have.property('timePickerVisible', false);
    expect(defaultLayout).to.have.property('chartAreaWidthPx', MIN_CHART_AREA_WIDTH_PX);
    expect(defaultLayout).to.have.property('mouseOverTime', null);
  });

  it('makes time picker visible', () => {
    const laidOut = layout(undefined, makeTimePickerVisible);
    expect(laidOut).to.have.property('timePickerVisible', true);
    expect(laidOut).to.have.property('chartAreaWidthPx', MIN_CHART_AREA_WIDTH_PX);
    expect(laidOut).to.have.property('mouseOverTime', null);
  });

  it('sets chart area width', () => {
    const laidOut = layout(undefined, setChartAreaWidth);
    expect(laidOut).to.have.property('timePickerVisible', false);
    expect(laidOut).to.have.property('chartAreaWidthPx', 1293);
    expect(laidOut).to.have.property('mouseOverTime', null);
  });

  it('sets time picker visibility', () => {
    const laidOut = layout(undefined, setMouseOverTime);
    expect(laidOut).to.have.property('timePickerVisible', false);
    expect(laidOut).to.have.property('chartAreaWidthPx', MIN_CHART_AREA_WIDTH_PX);
    expect(laidOut).to.have.property('mouseOverTime', 90210);
  });
});
