// @flow
// (Copyright) [2016 - 2016] Confluent, Inc.
import { encodeFieldName, serializeValues } from 'utils/connector';

describe('utils/connector', () => {
  describe('encodeFieldName', () => {
    it('removes periods from field name', () => {
      expect(encodeFieldName('topic')).to.equal('topic');
      expect(encodeFieldName('tasks.max')).to.equal('tasks-period-max');
      expect(encodeFieldName('retry.backoff.ms')).to.equal('retry-period-backoff-period-ms');
    });
  });

  describe('serializeValues', () => {
    it('filters empty values', () => {
      const values = {
        notEmpty: 'notEmpty',
        empty1: undefined,
        empty2: null,
        empty3: '',
        empty4: [],
        alsoNotEmpty: 'alsoNotEmpty',
        notEmptyArray: ['notEmptyArray']
      };

      expect(serializeValues(values)).to.have.all.keys(['notEmpty', 'alsoNotEmpty', 'notEmptyArray']);
    });

    it('converts arrays to strings', () => {
      const values = {
        arrayVal: ['also', 'Not', 'An', 'Empty', 'Array']
      };
      expect(serializeValues(values).arrayVal).to.equal('also,Not,An,Empty,Array');
    });

    it('encodes field name keys', () => {
      const values = {
        'some-period-field': 'some.field'
      };
      expect(serializeValues(values)).to.deep.eql({
        'some.field': 'some.field'
      });
    });
  });
});
