// (Copyright) [2016 - 2016] Confluent, Inc.
package io.confluent.controlcenter.example;

import com.google.common.collect.Lists;
import com.google.inject.Inject;

import org.apache.kafka.clients.CommonClientConfigs;
import org.apache.kafka.clients.producer.KafkaProducer;
import org.apache.kafka.clients.producer.ProducerConfig;
import org.apache.kafka.clients.producer.ProducerRecord;
import org.apache.kafka.clients.producer.RecordMetadata;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import java.util.Collections;
import java.util.List;
import java.util.Properties;
import java.util.concurrent.Future;
import java.util.concurrent.TimeUnit;

import io.confluent.controlcenter.ControlCenterConfig;
import io.confluent.monitoring.clients.interceptor.MonitoringInterceptorConfig;

final class FakeProducer implements Runnable {

  private static final Logger log = LoggerFactory.getLogger(FakeProducer.class);

  private final List<String> topics;
  private final ControlCenterConfig config;

  private String id;

  @Inject
  public FakeProducer(List<String> topics, ControlCenterConfig config) {
    if (topics != null) {
      this.topics = topics;
    } else {
      this.topics = Lists.newArrayList();
    }
    this.config = config;
  }

  public void setId(String id) {
    this.id = id;
  }

  public List<String> getTopics() {
    return topics;
  }

  public void run() {
    try {
      Properties properties = new Properties();
      properties.put(CommonClientConfigs.BOOTSTRAP_SERVERS_CONFIG, config.getList("bootstrap.servers"));
      properties.put(CommonClientConfigs.CLIENT_ID_CONFIG, "myproducer");
      if (this.id != null) {
        properties.put(CommonClientConfigs.CLIENT_ID_CONFIG, id);
      }
      properties.put(ProducerConfig.VALUE_SERIALIZER_CLASS_CONFIG, "org.apache.kafka.common.serialization.LongSerializer");
      properties.put(ProducerConfig.KEY_SERIALIZER_CLASS_CONFIG, "org.apache.kafka.common.serialization.StringSerializer");
      properties.put(
          ProducerConfig.INTERCEPTOR_CLASSES_CONFIG,
          "io.confluent.monitoring.clients.interceptor.MonitoringProducerInterceptor"
      );
      for (String s : Lists.newArrayList("", MonitoringInterceptorConfig.MONITORING_INTERCEPTOR_PREFIX)) {
//        properties.put(s + CommonClientConfigs.SECURITY_PROTOCOL_CONFIG, "SSL");
//        properties.put(s + SslConfigs.SSL_TRUSTSTORE_LOCATION_CONFIG, "/Users/norwood/clients/kafka/server.truststore.jks");
//        properties.put(s + SslConfigs.SSL_TRUSTSTORE_PASSWORD_CONFIG, "password");
//        properties.put(s + SslConfigs.SSL_KEYSTORE_LOCATION_CONFIG, "/Users/norwood/clients/kafka/server.keystore.jks");
//        properties.put(s + SslConfigs.SSL_KEYSTORE_PASSWORD_CONFIG, "password");
      }

      KafkaProducer<String, Long> producer = new KafkaProducer<String, Long>(properties);
      while (true) {
        try {
          Collections.shuffle(topics);
          String topic = topics.get(0);
          Future<RecordMetadata> f = producer.send(new ProducerRecord<String, Long>(topic, System.currentTimeMillis()));
          long sleepyTime = Math.round(Math.random() * 150) + 100;
          try {
            log.trace("wrote={}", f.get(Math.round(sleepyTime * .75), TimeUnit.MILLISECONDS));
          } catch (Throwable t) {
            log.error("whoops", t);
          }
          Thread.sleep(sleepyTime);
        } catch (InterruptedException e) {
          log.error("producer", e);
        }
      }
    } catch (Exception e) {
      e.printStackTrace();
    }
  }
}
